import { STATUS } from './DkValues';
/** 기본 테이블 생성시 받은 정보 */
export interface IInitTable {
    dbName: string;
    tbl: {
        app: boolean;
        appVersion: boolean;
        user: boolean;
        role: boolean;
        accessToken: boolean;
        userRole: boolean;
        userApps: boolean;
        userTerminal: boolean;
        menus: boolean;
        mqttUser: boolean;
        mqttAcl: boolean;
        files: boolean;
        fcmArrivalTmp: boolean;
        fcmHistoryTmp: boolean;
        fcmHistory: boolean;
        config: boolean;
        authCode: boolean;
        confirmIp: boolean;
        reservedUserId: boolean;
        sequence: boolean;
        template: boolean;
        urlKey: boolean;
        board: boolean;
        category: boolean;
        document: boolean;
        comment: boolean;
        tag: boolean;
        documentFiles: boolean;
        documentLink: boolean;
        documentPin: boolean;
        documentRead: boolean;
        documentTag: boolean;
        likeBlame: boolean;
    };
}
/** 파일 정보 */
export interface IFile {
    id: string;
    name: string;
    origName: string;
    contentType: string;
    urlPath: string;
    isPriv: boolean;
    size: number;
    width: number;
    height: number;
    thumbnailUrlPath: string;
    isThumbnailPriv: boolean;
    thumbnailSize: number;
    thumbnailWidth: number;
    thumbnailHeight: number;
    description: string;
    osrl?: number;
    filePath?: string;
    s3Bucket?: string;
    s3Key?: string;
    s3Region?: string;
    thumbnailFilePath?: string;
    thumbnailS3Bucket?: string;
    thumbnailS3Key?: string;
    thumbnailS3Region?: string;
    ipaddress?: string;
    used?: {
        [key: string]: any;
    };
    userId?: string;
    deleted?: boolean;
    create?: number;
    update?: number;
}
/** Role 정보 */
export interface IRole {
    id: string;
    name: string;
    osrl?: number;
    roleType?: number;
    defaultGroup?: boolean;
    description?: string;
    status?: STATUS;
    deleted?: boolean;
    create?: number;
    update?: number;
}
/** 메뉴 정보 */
export interface IMenu {
    id: string;
    parentId: string;
    name: string;
    urlPath: string;
    extra: {
        [key: string]: any;
    };
    depth: number;
    listOrder: number;
    rcPageName: string;
    rcIcon: string;
    isFirstPage: boolean;
    osrl?: number;
    parentOsrl?: number;
    roleOsrl?: number;
    status?: STATUS;
    templateOsrl?: number;
    reserve1?: string;
    reserve2?: string;
    reserve3?: string;
    create?: number;
    update?: number;
}
/** access token 정보 */
export interface IAccessToken {
    token: string;
    expireDate: number;
    issueDate: number;
    extra: {
        [key: string]: any;
    };
    osrl?: number;
    id?: string;
    userSrl?: number;
    appId?: number;
    roleId?: number;
    templateId?: number;
    create?: number;
    update?: number;
}
/** app version 정보 */
export interface IAppVersion {
    id: string;
    version: number;
    displayVersion: string;
    requireUpdate: boolean;
    downloadUrl: string;
    description: string;
    osrl?: number;
    deleted?: boolean;
    create?: number;
    update?: number;
}
/** 서버에 등록한 환경 설정값 정보 */
export interface ISimpleConfig {
    osrl: number;
    id: string;
    name: string;
    val: string;
    type: number;
    description: string;
    create: number;
    update: number;
}
/** 허용/차단 IP 정보 */
export interface IConfirmIp {
    osrl: number;
    id: string;
    roleId: string;
    cidr: string;
    deny: boolean;
    status: number;
    description: string;
    create: number;
    update: number;
}
/** 템플릿 정보 */
export interface ITemplate {
    osrl: number;
    id: string;
    name: string;
    groupName: string;
    extra: {
        [key: string]: any;
    };
    description: string;
    create: number;
    update: number;
}
/** 태그 정보 */
export interface ITag {
    id: string;
    name: string;
    common: boolean;
    osrl?: number;
    userId?: string;
    create?: number;
}
/** 게시판 정보 */
export interface IBoard {
    id: string;
    name: string;
    extra: {
        [key: string]: any;
    };
    listOrder: number;
    osrl?: number;
    status?: STATUS;
    description?: string;
    templateId?: string;
    create?: number;
    update?: number;
}
/** 게시판 카테고리 정보 */
export interface IBoardCategory {
    id: string;
    name: string;
    link: boolean;
    extra: {
        [key: string]: any;
    };
    listOrder: number;
    osrl?: number;
    boardOsrl?: number;
    closed?: boolean;
    status?: STATUS;
    description?: string;
    templateId?: string;
    create?: number;
    update?: number;
    board?: IBoard;
}
/** 게시물 정보 */
export interface IBoardDoc {
    osrl: number;
    id: string;
    title: string;
    document: string;
    secret: boolean;
    readCount: number;
    likeCount: number;
    blameCount: number;
    pinCount: number;
    commentCount: number;
    fileCount: number;
    status: STATUS;
    noComment: boolean;
    ipaddress: string;
    userId: string;
    userName: string;
    userNickname: string;
    emailAddress: string;
    templateId: string;
    extra: {
        [key: string]: any;
    };
    listOrder: number;
    isTop: boolean;
    create: number;
    update: number;
    template?: ITemplate;
    files?: Array<IFile>;
    tags?: Array<ITag>;
    category?: IBoardCategory;
}
/** 목록을 요청하는 API Request 에 항상 포함되는 값 */
export interface IReqListBase {
    offset: number;
    limit: number;
}
/** API Response 에 항상 포함 되는 값 */
export interface IResBase {
    ckTid: string;
    ckError: string;
    ckMessage: string;
}
/** 목록을 받은 API Response 에 항상 포함되는 값 */
export interface IResListBase extends IResBase {
    offset: number;
    limit: number;
    total: number;
}
/** 데이터 삭제 Request */
export interface IReqRemoveOne {
    id: string;
}
export interface IReqRemove {
    ids: Array<string>;
}
export interface IResRemove extends IResBase {
    count: number;
}
/** 데이터 단일 조회 Request */
export interface IReqInfo {
    id: string;
}
/** 데이터 순서 변경 */
export interface IReqChangeOrder {
    srcId: string;
    destId: string;
}
export interface IResChangeOrder extends IResBase {
    count: number;
}
/** 수정 Response */
export interface IResMod extends IResBase {
    count: number;
}
