"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = __importDefault(require("crypto-js/core"));
var md5_1 = __importDefault(require("crypto-js/md5"));
var sha256_1 = __importDefault(require("crypto-js/sha256"));
var hmac_sha256_1 = __importDefault(require("crypto-js/hmac-sha256"));
var enc_base64_1 = __importDefault(require("crypto-js/enc-base64"));
var enc_utf8_1 = __importDefault(require("crypto-js/enc-utf8"));
var enc_hex_1 = __importDefault(require("crypto-js/enc-hex"));
var aes_1 = __importDefault(require("crypto-js/aes"));
var pad_pkcs7_1 = __importDefault(require("crypto-js/pad-pkcs7"));
var DkValues_1 = require("../DkValues");
var CkStorage_1 = __importDefault(require("./CkStorage"));
var CkCrypto = (function () {
    function CkCrypto() {
    }
    CkCrypto.findApiKeyAndSecret = function () {
        var apiKeySecret = CkStorage_1.default.find(DkValues_1.DOTENV.KEY_API_KEY_SECRET);
        if (!apiKeySecret || !apiKeySecret.apiKey || !apiKeySecret.apiSecret) {
            CkCrypto.API_KEY = DkValues_1.API_CONFIG.KEY;
            CkCrypto.API_SECRET = DkValues_1.API_CONFIG.SECRET;
            return;
        }
        CkCrypto.READ_API_KEY_SCRET = true;
        CkCrypto.API_KEY = apiKeySecret.apiKey;
        CkCrypto.API_SECRET = apiKeySecret.apiSecret;
    };
    CkCrypto.hmacSha256Hash2 = function (method, urlPath, requestBody, contentType, date, secret) {
        if (!secret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var md5Body = '';
        if (requestBody) {
            var rBody = '';
            if (typeof requestBody === 'object') {
                try {
                    rBody = JSON.stringify(requestBody);
                }
                catch (err) {
                    console.error("[".concat(this.name, "]invalid request body json for hmac-sha256. [").concat(requestBody, "]"));
                }
            }
            else {
                rBody = requestBody;
            }
            if (rBody.length > 0) {
                md5Body = CkCrypto.md5Hash(rBody).toString();
            }
        }
        console.log("[".concat(this.name, "] request md5 body [").concat(md5Body, "]"));
        var cType = (contentType === undefined ? 'application/json' : contentType);
        var hdate = date || (new Date()).toUTCString();
        var asecr = secret || CkCrypto.API_SECRET;
        var signaturePlain = "".concat(method.toUpperCase(), "\n").concat(md5Body, "\n").concat(cType, "\n").concat(hdate, "\n").concat(urlPath);
        console.log("[".concat(this.name, "] signature [").concat(signaturePlain, "], secret [").concat(asecr, "]"));
        var signatureSha = (0, hmac_sha256_1.default)(signaturePlain, asecr);
        var signature = enc_base64_1.default.stringify(signatureSha);
        console.log("[".concat(this.name, "] hmac-sha256 signature [").concat(signature, "]"));
        return { signature: signature, hdate: hdate };
    };
    CkCrypto.hmacSha256HashForFile2 = function (urlPath, date, secret) {
        if (!secret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var md5Body = CkCrypto.md5Hash(DkValues_1.DOTENV.FILE_KEY).toString();
        console.log("[".concat(this.name, "] request md5 body [").concat(md5Body, "]"));
        var hdate = date || (new Date()).toUTCString();
        var asecr = secret || CkCrypto.API_SECRET;
        var signaturePlain = "".concat(DkValues_1.HTTP_METHOD.POST, "\n").concat(md5Body, "\n").concat(hdate, "\n").concat(urlPath);
        console.log("[".concat(this.name, "] signature [").concat(signaturePlain, "], secret [").concat(asecr, "]"));
        var signatureSha = (0, hmac_sha256_1.default)(signaturePlain, asecr);
        var signature = enc_base64_1.default.stringify(signatureSha);
        console.log("[".concat(this.name, "] hmac-sha256 signature [").concat(signature, "]"));
        return { signature: signature, hdate: hdate };
    };
    CkCrypto.getAPIHeader = function (method, urlPath, requestBody, acceptLang, contentType, hDate, apiKeyOrAccessToken, apiSecret, isBearer) {
        if (!apiSecret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var sig = CkCrypto.hmacSha256Hash2(method, urlPath, requestBody, contentType, hDate, apiSecret);
        var aKey = apiKeyOrAccessToken || CkCrypto.API_KEY;
        var type = isBearer ? 'Bearer' : 'Open';
        var ret = {
            Accept: 'application/json',
            'Accept-Language': acceptLang || 'ko',
            'H-Date': sig.hdate,
            'H-Authorization': "".concat(type, " ").concat(aKey, ":").concat(sig.signature),
        };
        if (contentType) {
            ret['Content-Type'] = contentType;
        }
        return ret;
    };
    CkCrypto.getAPIHeaderForFile = function (urlPath, acceptLang, hDate, apiKeyOrAccessToken, apiSecret, isBearer) {
        if (!apiSecret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var sig = CkCrypto.hmacSha256HashForFile2(urlPath, hDate, apiSecret);
        var aKey = apiKeyOrAccessToken || CkCrypto.API_KEY;
        var type = isBearer ? 'Bearer' : 'Open';
        var ret = {
            Accept: 'application/json',
            'Accept-Language': acceptLang || 'ko',
            'H-Date': sig.hdate,
            'H-Authorization': "".concat(type, " ").concat(aKey, ":").concat(sig.signature),
            'H-File-Key': DkValues_1.DOTENV.FILE_KEY,
        };
        return ret;
    };
    CkCrypto.bufferToWordArray = function (buf) {
        var wa = [];
        for (var i = 0, len = buf.length; i < len; i += 1) {
            wa[(i / 4) | 0] |= buf[i] << (24 - 8 * i);
        }
        return core_1.default.lib.WordArray.create(wa, buf.length);
    };
    CkCrypto.wordArrayToBuffer = function (wordArray) {
        var l = wordArray.sigBytes;
        var words = wordArray.words;
        var result = new Uint8Array(l);
        var i = 0;
        var j = 0;
        while (true) {
            if (i === l) {
                break;
            }
            var w = words[j];
            j += 1;
            result[i] = (w & 0xff000000) >>> 24;
            i += 1;
            if (i === l) {
                break;
            }
            result[i] = (w & 0x00ff0000) >>> 16;
            i += 1;
            if (i === l) {
                break;
            }
            result[i] = (w & 0x0000ff00) >>> 8;
            i += 1;
            if (i === l) {
                break;
            }
            result[i] = (w & 0x000000ff);
            i += 1;
        }
        return result.buffer.slice(result.byteOffset, result.byteLength + result.byteOffset);
    };
    CkCrypto.getOpenAPIAxiosOptions = function (method, urlPath, acceptLang, requestBody, qs, contentType, hDate, apiKey, apiSecret) {
        var ret = {
            method: method.toUpperCase(),
            url: "".concat(DkValues_1.API_HOST).concat(urlPath),
            headers: CkCrypto.getAPIHeader(method, urlPath, requestBody, acceptLang, contentType, hDate, apiKey, apiSecret),
            timeout: DkValues_1.API_CONFIG.TIMEOUT,
        };
        if (requestBody) {
            ret.data = requestBody;
        }
        if (qs) {
            ret.params = qs;
        }
        return ret;
    };
    CkCrypto.getBearerAPIAxiosOptions = function (method, urlPath, acceptLang, requestBody, qs, contentType, hDate, accessToken, apiSecret) {
        var ret = {
            method: method.toUpperCase(),
            url: "".concat(DkValues_1.API_HOST).concat(urlPath),
            headers: CkCrypto.getAPIHeader(method, urlPath, requestBody, acceptLang, contentType, hDate, accessToken, apiSecret, true),
            timeout: DkValues_1.API_CONFIG.TIMEOUT,
        };
        if (requestBody) {
            ret.data = requestBody;
        }
        if (qs) {
            ret.params = qs;
        }
        return ret;
    };
    CkCrypto.getBearerAPIAxiosOptionsForFile = function (file, urlPath, acceptLang, qs, hDate, accessToken, apiSecret) {
        var formData = new FormData();
        formData.append(DkValues_1.DOTENV.FILE_KEY, file);
        var ret = {
            method: DkValues_1.HTTP_METHOD.POST,
            url: "".concat(DkValues_1.API_HOST).concat(urlPath),
            headers: CkCrypto.getAPIHeaderForFile(urlPath, acceptLang, hDate, accessToken, apiSecret, true),
            timeout: DkValues_1.API_CONFIG.TIMEOUT,
            data: formData,
        };
        if (qs) {
            ret.params = qs;
        }
        return ret;
    };
    CkCrypto.md5Hash = function (value) {
        if (typeof value === 'string') {
            return (0, md5_1.default)(value).toString();
        }
        var wordArr = CkCrypto.bufferToWordArray(value);
        return (0, md5_1.default)(wordArr).toString();
    };
    CkCrypto.sha256Hash = function (value) {
        return (0, sha256_1.default)(value).toString(enc_base64_1.default);
    };
    CkCrypto.encodeBase64 = function (value) {
        var wordArr;
        if (typeof value === 'string') {
            wordArr = core_1.default.enc.Utf8.parse(value);
        }
        else {
            wordArr = CkCrypto.bufferToWordArray(value);
        }
        return enc_base64_1.default.stringify(wordArr);
    };
    CkCrypto.decodeBase64 = function (value, isBuffer) {
        var wordArr = enc_base64_1.default.parse(value);
        if (isBuffer) {
            return CkCrypto.wordArrayToBuffer(wordArr);
        }
        return wordArr.toString(core_1.default.enc.Utf8);
    };
    CkCrypto.encodeHex = function (value) {
        var wordArr;
        if (typeof value === 'string') {
            wordArr = core_1.default.enc.Utf8.parse(value);
        }
        else {
            wordArr = CkCrypto.bufferToWordArray(value);
        }
        return core_1.default.enc.Hex.stringify(wordArr);
    };
    CkCrypto.decodeHex = function (value, isBuffer) {
        var wordArr = core_1.default.enc.Hex.parse(value);
        if (isBuffer) {
            return CkCrypto.wordArrayToBuffer(wordArr);
        }
        return core_1.default.enc.Utf8.stringify(wordArr);
    };
    CkCrypto.encryptAES = function (value, secretKey, iv, isByHex) {
        var cipher = aes_1.default.encrypt(value, enc_utf8_1.default.parse(secretKey), {
            iv: enc_utf8_1.default.parse(iv),
            padding: pad_pkcs7_1.default,
            mode: core_1.default.mode.CBC,
        });
        if (isByHex) {
            var word = enc_utf8_1.default.parse(cipher.toString());
            return enc_hex_1.default.stringify(word);
        }
        return cipher.toString();
    };
    CkCrypto.decryptAES = function (value, secretKey, iv, isByHex) {
        if (isByHex) {
            var word = enc_hex_1.default.parse(value);
            value = enc_utf8_1.default.stringify(word);
        }
        var decipher = aes_1.default.decrypt(value, enc_utf8_1.default.parse(secretKey), {
            iv: enc_utf8_1.default.parse(iv),
            padding: pad_pkcs7_1.default,
            mode: core_1.default.mode.CBC,
        });
        return decipher.toString(enc_utf8_1.default);
    };
    CkCrypto.READ_API_KEY_SCRET = false;
    CkCrypto.API_KEY = '';
    CkCrypto.API_SECRET = '';
    return CkCrypto;
}());
exports.default = CkCrypto;
