"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var CkUtils_1 = __importDefault(require("./CkUtils"));
var CkCrypto_1 = __importDefault(require("./CkCrypto"));
var DkValues_1 = require("../DkValues");
var CkStorage = (function () {
    function CkStorage() {
    }
    CkStorage.read = function (skey, isSession) {
        if (!skey) {
            return null;
        }
        if (typeof window === 'undefined') {
            return null;
        }
        if (!window.localStorage || !window.sessionStorage) {
            console.warn("[".concat(this.name, "] cannot read storage value. not support localStorage, sessionStorage. need update web-browser version."));
            return null;
        }
        var value = (isSession ? window.sessionStorage.getItem(skey) : window.localStorage.getItem(skey));
        console.log("[".concat(this.name, "] read key [").concat(skey, "]"));
        return value;
    };
    CkStorage.upsert = function (skey, value, isSession) {
        if (!skey) {
            return false;
        }
        if (typeof window === 'undefined') {
            return false;
        }
        if (!window.localStorage || !window.sessionStorage) {
            console.warn("[".concat(this.name, "] cannot upsert data to storage. not support localStorage, sessionStorage. need update web-browser version."));
            return false;
        }
        var _value = (typeof value === 'object' ? JSON.stringify(value) : value);
        if (isSession) {
            window.sessionStorage.setItem(skey, _value);
        }
        else {
            window.localStorage.setItem(skey, _value);
        }
        console.log("[".concat(this.name, "] upsert. key [").concat(skey, "]"));
        return true;
    };
    CkStorage.reloadSavedData = function (prevAesKey, newAesKey) {
        var refreshValue = function (skey) {
            var val = CkStorage.find(skey, prevAesKey);
            if (val === null) {
                return false;
            }
            return CkStorage.save(skey, val, false, newAesKey);
        };
        refreshValue(DkValues_1.DOTENV.KEY_USER);
        refreshValue(DkValues_1.DOTENV.KEY_API_KEY_SECRET);
        refreshValue(DkValues_1.DOTENV.KEY_CONFIG);
        refreshValue(DkValues_1.DOTENV.KEY_MQTT);
        refreshValue(DkValues_1.DOTENV.KEY_SIDEBAR_MENU_TREE);
        refreshValue(DkValues_1.DOTENV.KEY_SIDEBAR_MENU_MAP);
        refreshValue(DkValues_1.DOTENV.KEY_LAST_PAGE);
    };
    CkStorage.initValue = function () {
        var rPrevAesKey = CkStorage.read(DkValues_1.DOTENV.KEY_AES_SECRET);
        if (!rPrevAesKey) {
            return CkStorage.save('', '', true);
        }
        var prevAesKey = rPrevAesKey.split('').reverse().join('');
        CkStorage.save('', '', true);
        var raesKey = CkStorage.read(DkValues_1.DOTENV.KEY_AES_SECRET);
        if (!raesKey) {
            console.error("[".concat(this.name, "] not found secret value"));
            return false;
        }
        var currAesKey = raesKey.split('').reverse().join('');
        CkStorage.reloadSavedData(prevAesKey, currAesKey);
        return true;
    };
    CkStorage.save = function (skey, value, isFirst, aesKey, isSession) {
        if (isFirst) {
            var uuid = CkUtils_1.default.getUUIDV5("".concat(CkUtils_1.default.getUUID(), "-").concat(Date.now())) + CkUtils_1.default.getUUIDV4() + CkUtils_1.default.getUUIDV4() + CkUtils_1.default.getUUIDV4();
            var ruuid = uuid.split('').reverse().join('');
            return CkStorage.upsert(DkValues_1.DOTENV.KEY_AES_SECRET, ruuid);
        }
        var _aesKey = aesKey;
        if (!_aesKey) {
            var raesKey = CkStorage.read(DkValues_1.DOTENV.KEY_AES_SECRET) || '';
            if (!raesKey) {
                console.error("[".concat(this.name, "] not found secret value"));
                return false;
            }
            _aesKey = raesKey.split('').reverse().join('');
        }
        var aesSecret = CkCrypto_1.default.md5Hash(_aesKey);
        var iv = aesSecret.substring(0, 8) + aesSecret.substring(24);
        var origVal = JSON.stringify(value).split('').reverse().join('');
        var encVal = CkCrypto_1.default.encryptAES(origVal, aesSecret, iv, true);
        return CkStorage.upsert(skey, encVal, isSession);
    };
    CkStorage.find = function (skey, aesKey, isSession) {
        var encData = CkStorage.read(skey, isSession);
        if (!encData) {
            return null;
        }
        var _aesKey = aesKey;
        if (!_aesKey) {
            var raesKey = CkStorage.read(DkValues_1.DOTENV.KEY_AES_SECRET);
            if (!raesKey) {
                console.error("[".concat(this.name, "] not found secret value"));
                return null;
            }
            _aesKey = raesKey.split('').reverse().join('');
        }
        var aesSecret = CkCrypto_1.default.md5Hash(_aesKey);
        var iv = aesSecret.substring(0, 8) + aesSecret.substring(24);
        var decVal = '';
        try {
            decVal = CkCrypto_1.default.decryptAES(encData, aesSecret, iv, true).split('').reverse().join('');
        }
        catch (err) {
            console.log("[".concat(this.name, "] invalid value for decryptAES. skey [").concat(skey, "], encData [").concat(encData, "], aesSecret [").concat(aesSecret, "], iv [").concat(iv, "]"));
            return null;
        }
        return JSON.parse(decVal);
    };
    CkStorage.remove = function (skey, isSession) {
        if (typeof window === 'undefined') {
            return;
        }
        if (!window.localStorage || !window.sessionStorage) {
            console.warn("[".concat(this.name, "] cannot delete data of storage. not support localStorage, sessionStorage. need update web-browser version."));
            return;
        }
        if (isSession === true) {
            window.sessionStorage.removeItem(skey);
        }
        else {
            window.localStorage.removeItem(skey);
        }
        console.log("[".concat(this.name, "] remove. key [").concat(skey, "]"));
    };
    return CkStorage;
}());
exports.default = CkStorage;
