"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidValue = exports.CUSTOM_BREADCRUMB_PAGE_KEY = exports.INIT_DB_CHECK_STATE = exports.JSON_FORM_TYPE = exports.RUNNING_STATE = exports.DOTENV = exports.MQTT_STATE = exports.MQTT_CONFIG = exports.API_RETURN_CODE = exports.DKAPI_ENDPOINT = exports.API_HOST = exports.API_CONFIG = exports.HTTP_HEADER_VALUE = exports.HTTP_METHOD = exports.API_REQUEST_STATE = exports.LOAD_STATE = exports.SUPPORT_LAYOUT_TYPE_LIST = exports.SUPPORT_LAYOUT_TYPE = exports.SUPPORT_THEME_CODE_LIST = exports.SUPPORT_THEME = exports.SUPPORT_LOCALE_CODE_LIST = exports.SUPPORT_LOCALE = exports.TABLE_PAGE_SIZES = exports.DRAWER_OPEN_TYPE = exports.USER_ROLE = exports.SIMPLE_CONFIG_TYPE = exports.TERMINAL = exports.STATUS = exports.YES_OR_NO = exports.GENDER = void 0;
/* eslint-disable import/no-extraneous-dependencies */
/**
 * 기본 값 설정이며, 서비스별 값 설정은 MyValues.ts 에서 하도록 한다.
 *
 * 프로그램에서 사용할 공통 값들을 여기에서 정의 한다.
 * 현재 한국어, 영어, 중국어 3개를 지원하도록 구성 되어 있으며, 만일 다른 locale 을 추가 해야 한다면 다음 작업을 해야 한다.
 *
 * - DkValues 파일에 dayjs import
 * - src/resource/i18n 에 언어 파일 추가
 * - DkValues.SUPPORT_LOCALE 에 언어 코드 추가
 * - PublicRouter.loadI18nResource 에 언어 코드에 맞는 리소스 파일 import 추가(import 내부에는 변수를 사용 불가 하기 때문에 별도로 몰아서 정의 불가능.)
 *
 * 테마가 추가 된다면, locale 과 같이 다음 작업을 한다.
 * - DkValues.SUPPORT_THEME 에 테마 코드 추가
 * - PublicRouter.loadThemeResource 에 theme code 에 맞는 리소스 파일 import 추가(import 내부에는 변수를 사용 불가 하기 때문에 별도로 몰아서 정의 불가능.)
 */
require("dayjs/locale/ko");
require("dayjs/locale/en");
require("dayjs/locale/zh-cn");
//=====================================
// 기본으로 포함되는 값 정의
//=====================================
/** 성별 구분 */
var GENDER = {
    /** 남성 */
    MALE: 1,
    /** 여성 */
    FEMALE: 2,
    /** 알 수 없음 */
    UNKNOWN: 3,
    /** 알리고 싶지 않음 */
    NO_COMMENT: 4,
};
exports.GENDER = GENDER;
/**
 * yes, no 구분
 */
var YES_OR_NO = {
    /** yes */
    YES: 1,
    /** no */
    NO: 2,
};
exports.YES_OR_NO = YES_OR_NO;
/**
 * 데이터의 활성 상태 구분
 */
var STATUS = {
    /** 활성 */
    ENABLE: 1,
    /** 중지 */
    PAUSE: 2,
    /** 비활성 */
    DISABLE: 3,
};
exports.STATUS = STATUS;
/**
 * 접근하는 클라이언트 타입
 */
var TERMINAL = {
    /** 웹 브라우저 */
    WEB: 1,
    /** 안드로이드 앱 */
    ANDROID: 2,
    /** ios 앱 */
    IOS: 3,
    /** 서버 */
    SERVER: 100,
};
exports.TERMINAL = TERMINAL;
/**
 * 서버에 등록되는 간단한 환경 설정 종류
 */
var SIMPLE_CONFIG_TYPE = {
    /** reactjs 페이지명 */
    REACT_PAGE: {
        key: 1,
        text: 'setting.simpleConfig.reactPage',
    },
    /** 템플릿 그룹 */
    TEMPLATE_GROUP: {
        key: 2,
        text: 'setting.simpleConfig.templateGroup',
    },
    /** ANTD 아이콘 */
    ANTD_ICON: {
        key: 3,
        text: 'setting.simpleConfig.antdIcon',
    },
    /** 지원 언어 코드 */
    LANG_CODE: {
        key: 4,
        text: 'setting.simpleConfig.langCode',
    },
};
exports.SIMPLE_CONFIG_TYPE = SIMPLE_CONFIG_TYPE;
/** 지원하는 유저 Role. 서비스 마다 다를 수 있기 때문에, 서비스 별로 변경 해서 사용 해야 한다. */
var USER_ROLE = {
    /** root 관리자 */
    ROOT: {
        key: 1,
        label: 'overall.userRole.root',
    },
    /** 일반1 */
    NORMAL1: {
        key: 100,
        label: 'overall.userRole.normal1',
    },
};
exports.USER_ROLE = USER_ROLE;
/** 데이터 생성, 데이터 수정시 사용하는 drawer open 을 구별 */
var DRAWER_OPEN_TYPE = {
    /** 데이터 생성, 데이터 수정 구별 없이 open */
    OPEN: 1,
    /** 데이터 생성을 위해서 drawer open */
    OPEN_NEW: 2,
    /** 데이터 수정을 위해서 drawer open */
    OPEN_MOD: 3,
    /** drawer close */
    CLOSE: 100,
};
exports.DRAWER_OPEN_TYPE = DRAWER_OPEN_TYPE;
/** antd 테이블에서 보여줄 한 페이지에 보여줄 row 갯수를 선택 할 수 있는 목록 */
var TABLE_PAGE_SIZES = [15, 30, 50, 100];
exports.TABLE_PAGE_SIZES = TABLE_PAGE_SIZES;
if (process.env.NODE_ENV_TYPE) {
    // 개발자 개인 pc 환경이면 추가 된다.
    TABLE_PAGE_SIZES.unshift(2);
}
/**
 * 앱에서 지원하는 locale 설정. 지원하는 locale 이 추가되면 변경 되어야 한다.
 * 이것이 변경되면 LOCALE_RESOURCE 도 같이 변경 되어야 한다.
 */
var SUPPORT_LOCALE = {
    // 한국어
    ko_KR: 'ko_KR',
    // 영어
    en_US: 'en_US',
    // 중국어
    zh_CN: 'zh_CN',
};
exports.SUPPORT_LOCALE = SUPPORT_LOCALE;
var supportLocaleList = Object.keys(SUPPORT_LOCALE);
var SUPPORT_LOCALE_CODE_LIST = [];
exports.SUPPORT_LOCALE_CODE_LIST = SUPPORT_LOCALE_CODE_LIST;
for (var _i = 0, supportLocaleList_1 = supportLocaleList; _i < supportLocaleList_1.length; _i++) {
    var row = supportLocaleList_1[_i];
    SUPPORT_LOCALE_CODE_LIST.push(SUPPORT_LOCALE[row]);
}
/**
 * 지원 하는 테마 종류. 테마가 추가 되면 변경 되어야 한다.
 * themes 디렉토리에 지원하는 theme 의 값들이 정의 되어야 한다.
 */
var SUPPORT_THEME = {
    CLASSIC: 'classic',
    DARK: 'dark',
};
exports.SUPPORT_THEME = SUPPORT_THEME;
var supportThemeList = Object.keys(SUPPORT_THEME);
var SUPPORT_THEME_CODE_LIST = [];
exports.SUPPORT_THEME_CODE_LIST = SUPPORT_THEME_CODE_LIST;
for (var _a = 0, supportThemeList_1 = supportThemeList; _a < supportThemeList_1.length; _a++) {
    var row = supportThemeList_1[_a];
    SUPPORT_THEME_CODE_LIST.push(SUPPORT_THEME[row]);
}
/**
 * 지원하는 layout 타입.
 * 항목은 layout 지원되는 종류에 따라 추가 하거나, 삭제 한다.
 */
var SUPPORT_LAYOUT_TYPE = {
    A: 'a',
    B: 'b',
    C: 'c',
    D: 'd',
    E: 'e',
    F: 'f',
};
exports.SUPPORT_LAYOUT_TYPE = SUPPORT_LAYOUT_TYPE;
var supportLayoutTypeList = Object.keys(SUPPORT_LAYOUT_TYPE);
var SUPPORT_LAYOUT_TYPE_LIST = [];
exports.SUPPORT_LAYOUT_TYPE_LIST = SUPPORT_LAYOUT_TYPE_LIST;
for (var _b = 0, supportLayoutTypeList_1 = supportLayoutTypeList; _b < supportLayoutTypeList_1.length; _b++) {
    var row = supportLayoutTypeList_1[_b];
    SUPPORT_LAYOUT_TYPE_LIST.push(SUPPORT_LAYOUT_TYPE[row]);
}
/**
 * 리소스를 로딩하는 절차 정의
 */
var LOAD_STATE = {
    INIT: 1,
    LOADING: 2,
    COMPLETE: 3, // 로딩 완료
};
exports.LOAD_STATE = LOAD_STATE;
/**
 * Redux-thunk 로 API 를 호출 할 때, API 호출 상태.
 *
 * mqtt broker 에 메시지를 publish, subscribe 할 때도 사용 한다.
 * - PENDING : publish/subscribe 대기
 * - FULFILLED : publish/subscribe 성공
 * - REJECTED : publish/subscribe 실패
 */
var API_REQUEST_STATE = {
    INIT: 1,
    PENDING: 2,
    FULFILLED: 3,
    REJECTED: 4, // api request 완료(실패로 완료)
};
exports.API_REQUEST_STATE = API_REQUEST_STATE;
/** http header value */
var HTTP_HEADER_VALUE = {
    JSON: 'application/json',
};
exports.HTTP_HEADER_VALUE = HTTP_HEADER_VALUE;
/**
 * Rest API 호출 할 때, http method
 */
var HTTP_METHOD = {
    GET: 'GET',
    POST: 'POST',
    PUT: 'PUT',
    DELETE: 'DELETE',
};
exports.HTTP_METHOD = HTTP_METHOD;
/**
 * rest api 연결시에 사용될 고정값.
 */
var API_CONFIG = {
    KEY: process.env.REACT_APP_API_KEY || '',
    SECRET: process.env.REACT_APP_API_SECRET || '',
    HOST: process.env.REACT_APP_API_HOST || '',
    PORT: process.env.REACT_APP_API_PORT || '',
    TIMEOUT: Number(process.env.REACT_APP_API_TIMEOUT || '30000'),
};
exports.API_CONFIG = API_CONFIG;
var API_HOST = (API_CONFIG.PORT ? "".concat(API_CONFIG.HOST, ":").concat(API_CONFIG.PORT) : API_CONFIG.HOST);
exports.API_HOST = API_HOST;
var DKAPI_CORE_PREFIX = '/v1/admin';
/**
 * 기본 rest api 의 endpoint.
 * 서비스별 rest api 의 endpoint 는 MyValues.ts 에 정의 한다.
 */
var DKAPI_ENDPOINT = {
    /** 테이블 존재 및 데이터 생성 체크 */
    INIT_CHECK: "".concat(DKAPI_CORE_PREFIX, "/init/db/check"),
    /** 기본 테이블 생성 */
    INIT_TABLE: "".concat(DKAPI_CORE_PREFIX, "/init/db/table"),
    /** 기본 데이터 생성 */
    INIT_DATA: "".concat(DKAPI_CORE_PREFIX, "/init/db/data"),
    /** 접속 토큰 발급(로그인) - Open */
    LOGIN: "".concat(DKAPI_CORE_PREFIX, "/user/login"),
    /** 접속 토큰 폐기(로그 아웃) - Bearer */
    LOGOUT: "".concat(DKAPI_CORE_PREFIX, "/user/logout"),
    /** 접속 토큰 연장 - Bearer */
    ACCESS_TOKEN_CONTINUE: "".concat(DKAPI_CORE_PREFIX, "/user/access/token/continue"),
    /** Role 목록 - Bearer */
    ROLE_LIST: "".concat(DKAPI_CORE_PREFIX, "/role/list"),
    /** 메뉴 목록 - Bearer */
    MENU_LIST: "".concat(DKAPI_CORE_PREFIX, "/menu/list"),
    /** 메뉴 삭제(단일) - Bearer */
    MENU_DEL: "".concat(DKAPI_CORE_PREFIX, "/menu/remove"),
    /** 메뉴 추가 - Bearer */
    MENU_ADD: "".concat(DKAPI_CORE_PREFIX, "/menu"),
    /** 메뉴 수정 - Bearer */
    MENU_MOD: "".concat(DKAPI_CORE_PREFIX, "/menu"),
    /** 메뉴 상세 - Bearer */
    MENU_INFO: "".concat(DKAPI_CORE_PREFIX, "/menu"),
    /** 메뉴 순서 변경 - Bearer */
    MENU_CANGE_ORDER: "".concat(DKAPI_CORE_PREFIX, "/menu/lorder"),
    /** 간단한 환경 설정 목록 - Bearer */
    SIMPLE_CONFIG_LIST: "".concat(DKAPI_CORE_PREFIX, "/etc/config/list"),
    /** 간단한 환경 설정 삭제 - Bearer */
    SIMPLE_CONFIG_DEL: "".concat(DKAPI_CORE_PREFIX, "/etc/config/remove"),
    /** 간단한 환경 설정 추가 - Bearer */
    SIMPLE_CONFIG_ADD: "".concat(DKAPI_CORE_PREFIX, "/etc/config"),
    /** 간단한 환경 설정 수정 - Bearer */
    SIMPLE_CONFIG_MOD: "".concat(DKAPI_CORE_PREFIX, "/etc/config"),
    /** 간단한 환경 설정 조회 - Bearer */
    SIMPLE_CONFIG_INFO: "".concat(DKAPI_CORE_PREFIX, "/etc/config"),
    /** 로그인 허용/차단 IP 목록 - Bearer */
    CONFIRM_IP_LIST: "".concat(DKAPI_CORE_PREFIX, "/etc/allow/deny/cidr/list"),
    /** 로그인 허용/차단 IP 삭제 - Bearer */
    CONFIRM_IP_DEL: "".concat(DKAPI_CORE_PREFIX, "/etc/allow/deny/cidr/remove"),
    /** 로그인 허용/차단 IP 추가 - Bearer */
    CONFIRM_IP_ADD: "".concat(DKAPI_CORE_PREFIX, "/etc/allow/deny/cidr"),
    /** 로그인 허용/차단 IP 수정 - Bearer */
    CONFIRM_IP_MOD: "".concat(DKAPI_CORE_PREFIX, "/etc/allow/deny/cidr"),
    /** 로그인 허용/차단 IP 조회 - Bearer */
    CONFIRM_IP_INFO: "".concat(DKAPI_CORE_PREFIX, "/etc/allow/deny/cidr"),
    /** 템플릿 목록 - Bearer */
    TMPL_LIST: "".concat(DKAPI_CORE_PREFIX, "/template/list"),
    /** 템플릿 삭제 - Bearer */
    TMPL_DEL: "".concat(DKAPI_CORE_PREFIX, "/template/remove"),
    /** 템플릿 추가 - Bearer */
    TMPL_ADD: "".concat(DKAPI_CORE_PREFIX, "/template"),
    /** 템플릿 수정 - Bearer */
    TMPL_MOD: "".concat(DKAPI_CORE_PREFIX, "/template"),
    /** 템플릿 조회 - Bearer */
    TMPL_INFO: "".concat(DKAPI_CORE_PREFIX, "/template"),
    /** 파일 업로드 - Bearer */
    FILE_UPLOAD: "".concat(DKAPI_CORE_PREFIX, "/file/upload"),
    /** 게시물 목록 - Bearer */
    DOC_LIST: "".concat(DKAPI_CORE_PREFIX, "/board/document/list"),
    /** 게시물 조회 - Bearer */
    DOC_INFO: "".concat(DKAPI_CORE_PREFIX, "/board/document"),
    /** 게시물 생성 - Bearer */
    DOC_ADD: "".concat(DKAPI_CORE_PREFIX, "/board/document"),
    /** 게시물 수정 - Bearer */
    DOC_MOD: "".concat(DKAPI_CORE_PREFIX, "/board/document"),
    /** 게시물 목록 - Bearer */
    DOC_DELETE: "".concat(DKAPI_CORE_PREFIX, "/board/document/remove"),
};
exports.DKAPI_ENDPOINT = DKAPI_ENDPOINT;
/**
 * rest api 의 리턴 코드.
 * 기본으로 성공 코드는 정의 되어 있고, 에러 코드 구분이 필요하면 추가 하도록 한다.
 * 서비스별 에러 코드는 MyValues 에 등록 하도록 한다.
 */
var API_RETURN_CODE = {
    SUCCESS: 'S000001',
    INVALID_AUTH: 'E000004', // 인증 실패 - http code 401
};
exports.API_RETURN_CODE = API_RETURN_CODE;
/**
 * mqtt broker 연결 사용시 broker 연결 정보
 */
var MQTT_CONFIG = {
    PROTOCOL: "".concat(process.env.REACT_APP_MQTT_PROTOCOL),
    HOST: "".concat(process.env.REACT_APP_MQTT_HOST),
    PORT: Number(process.env.REACT_APP_MQTT_PORT),
    KEEP_ALIVE: Number(process.env.REACT_APP_MQTT_KEEP_ALIVE),
    RECONNECT_PERIOD: Number(process.env.REACT_APP_MQTT_RECONNECT_PERIOD),
    QOS: Number(process.env.REACT_APP_MQTT_QOS),
    USER_ID: "".concat(process.env.REACT_APP_MQTT_USER_ID),
    PASSWORD: "".concat(process.env.REACT_APP_MQTT_PASSWORD),
    CLIENT_ID: "".concat(process.env.REACT_APP_MQTT_CLIENT_ID),
    RECV_MAX_MSG_COUNT: Number(process.env.REACT_APP_MQTT_RECV_MAX_MSG_COUNT),
    RECV_DELAY: Number(process.env.REACT_APP_MQTT_RECV_DELAY),
    RECV_BUFFER_SIZE: Number(process.env.REACT_APP_MQTT_RECV_BUFFER_SIZE),
    AUTO_CONNECT: "".concat(process.env.REACT_APP_MQTT_AUTO_CONNECT).toLowerCase() === 'true',
    AUTO_SUBSCRIBE_TOPICS: JSON.parse("".concat(process.env.REACT_APP_MQTT_AUTO_SUBSCRIBE_TOPICS)),
};
exports.MQTT_CONFIG = MQTT_CONFIG;
/**
 * mqtt broker 연결 상태
 * - INIT : mqtt broker 최초 연결 시도 이전. 초기값
 * - CONNECTING : 연결중
 * - RECONNECTING : 재 연결중
 * - CONNECTED : 연결 됨
 * - FAILED : 연결 실패
 * - DISCONNECT : 연결 종료. end 함수로 클라이언트가 연결 종료 시킴
 */
var MQTT_STATE = {
    INIT: 1,
    CONNECTING: 2,
    RECONNECTING: 3,
    CONNECTED: 4,
    FAILED: 5,
    DISCONNECT: 6,
    DISCONNECT_FORCE: 7, // 유저가 강제로 끊음.
};
exports.MQTT_STATE = MQTT_STATE;
/**
 * dotenv 를 통해서 주입된 값
 */
var appVersion = (process.env.NODE_ENV_TYPE ? "".concat(process.env.APP_VERSION, ".").concat(process.env.NODE_ENV, ".").concat(process.env.NODE_ENV_TYPE) : "".concat(process.env.APP_VERSION, ".").concat(process.env.NODE_ENV));
var DOTENV = {
    /** time zone */
    TIME_ZONE: "".concat(process.env.REACT_APP_TIME_ZONE),
    /** url path 앞에 고정으로 붙을 prefix url */
    URL_PREFIX: "".concat(process.env.REACT_APP_URL_PREFIX),
    /** 앱의 버전. package.json 의 version 값에 추가로 더 한 것 */
    VERSION: appVersion,
    /** 설치를 위해 테이블 및 기본 데이터 생성을 위한 api key */
    INIT_DB_DATA_AUTH_APP_KEY: "".concat(process.env.REACT_APP_INIT_DB_DATA_AUTH_APP_KEY),
    /** 설치를 위해 테이블 및 기본 데이터 생성을 위한 api signature */
    INIT_DB_DATA_AUTH_SIGNATURE_KEY: "".concat(process.env.REACT_APP_INIT_DB_DATA_AUTH_SIGNATURE_KEY),
    /** local storage 또는 session storage 에 저장되는 데이터를 암호화 하기 위한 aes key, iv 를 저장하는 키 */
    KEY_AES_SECRET: "".concat(process.env.REACT_APP_KEY_AES_SECRET),
    /** Rest API 에 사용하는 api key, api secret 를 저장하는 키. 로그인 이후 api key, api secret 가 바뀌기 때문에 필요함. */
    KEY_API_KEY_SECRET: "".concat(process.env.REACT_APP_KEY_API_KEY_SECRET),
    /** 로그인 유지를 위해, 유저 정보를 저장하는 키. access token 도 유저 정보에 포함되어 있음 */
    KEY_USER: "".concat(process.env.REACT_APP_KEY_USER),
    /** locale code, theme code 등의 환경을 저장하는 키 */
    KEY_CONFIG: "".concat(process.env.REACT_APP_KEY_CONFIG),
    /** mqtt broker 에 자동으로 연결 하기 위한 값을 저장하는 키 */
    KEY_MQTT: "".concat(process.env.REACT_APP_KEY_MQTT),
    /** 사이드바에 출력되는 메뉴 목록을 저장하는 키. tree 형태 */
    KEY_SIDEBAR_MENU_TREE: "".concat(process.env.REACT_APP_KEY_SIDEBAR_MENU_TREE),
    /** 사이드바에 출력되는 메뉴 목록을 저장하는 키. map 형태. 이동하기 위한 url path 를 구하기 위한 값 */
    KEY_SIDEBAR_MENU_MAP: "".concat(process.env.REACT_APP_KEY_SIDEBAR_MENU_MAP),
    /** 최종 사용한 페이지 정보가 저장되는 local storage 에서 키 */
    KEY_LAST_PAGE: "".concat(process.env.REACT_APP_KEY_LAST_PAGE),
    /** 기본으로 사용하는 DB 데이터가 없을때, 기본 데이터를 생성하는 페이지 url path. REACT_APP_URL_PREFIX 을 제외한 값*/
    URL_PATH_DB_DATA_INIT: "".concat(process.env.REACT_APP_URL_PATH_DB_DATA_INIT),
    /** 로그인 페이지 url path. REACT_APP_URL_PREFIX 을 제외한 값 */
    URL_PATH_LOGIN: "".concat(process.env.REACT_APP_URL_PATH_LOGIN),
    /** 인증이 필요한 페이지 접근시 인증 되지 않았 을 때 보여줄 페이지의 url path. REACT_APP_URL_PREFIX 을 제외한 값 */
    URL_PATH_NO_AUTH: "".concat(process.env.REACT_APP_URL_PATH_NO_AUTH),
    /** 인증 실패 페이지에서 자동으로 로그인 페이지로 이동할 시간. 초 단위 */
    NO_AUTH_AUTO_SEC: Number("".concat(process.env.REACT_APP_NO_AUTH_AUTO_SEC)),
    /** 파일 업로드시 사용하는 파일키 */
    FILE_KEY: "".concat(process.env.REACT_APP_FILE_KEY),
};
exports.DOTENV = DOTENV;
/**
 * running 하는 것들에 대한 상태 정의
 */
var RUNNING_STATE = {
    INIT: 1,
    RUNNING: 2,
    STOP: 3, // stop 됨
};
exports.RUNNING_STATE = RUNNING_STATE;
/**
 * component > common > FormJSONEditor 가 사용 되는 위치 구분.
 * 위치에 따라 그려지는 FormJSONEditor 가 약간의 변화가 있다.
 */
var JSON_FORM_TYPE = {
    /** 일반적으로 사용되는 경우. editing 가능한 jsoneditor 를 표시. 기본값 */
    NORMAL_EDITOR: 1,
    /** 일반적으로 사용되는 경우. view mode 로 jsoneditor 를 표시 */
    NORMAL_VIEW: 2,
    /** 메뉴 관리 페이지에서 사용되는 경우 */
    MENU: 3,
    /** 템플릿 관리 페이지에서 사용되는 경우 */
    TEMPLATE: 4,
};
exports.JSON_FORM_TYPE = JSON_FORM_TYPE;
/** 서버에서 받지 않은 페이지(사이드바 메뉴 트리에 등록되지 않는 페이지)를 breadcrumb 에 추가 하기 위해서 사용되는 메뉴 데이터 key */
var CUSTOM_BREADCRUMB_PAGE_KEY = '3061bf0e4b595c6a8618406b61737378';
exports.CUSTOM_BREADCRUMB_PAGE_KEY = CUSTOM_BREADCRUMB_PAGE_KEY;
var INIT_DB_CHECK_STATE = {
    PREV: 1,
    FAIL: 2,
};
exports.INIT_DB_CHECK_STATE = INIT_DB_CHECK_STATE;
/**
 * 모든 enum 값에 대해서 파라미터로 주어진 값이 정의된 값에 포함되어 있는지 체크 한다.
 * 다음과 같이 사용 한다.
 *
 * number 가 정의된 enum 일때는...
 * isValidValue<number>(TERMINAL, 1)
 *
 * string 이 정의된 enum 일때는...
 * isValidValue<string>(IMAGE_RESIZE_MODE, 'crop')
 * @param enumType enum 타입
 * @param checkValue 체크 할 값
 */
var isValidValue = function (enumType, checkValue) {
    var keys = Object.keys(enumType);
    for (var i = 0, len = keys.length; i < len; i += 1) {
        if (enumType[keys[i]] === checkValue) {
            return true;
        }
    }
    return false;
};
exports.isValidValue = isValidValue;
