"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var antd_1 = require("antd");
var react_router_dom_1 = require("react-router-dom");
var DkValues_1 = require("../DkValues");
var CkUtils_1 = __importDefault(require("../utils/CkUtils"));
/**
 * rest api 호출시 에러를 처리 하기 위한 공통 함수를 hook 한다.
 * 본 hook 을 포함하면 navigate 를 무조건 포함하게 된다.
 * 즉, withNavigate hook 도 같이 포함 시킨다.
 *
 * @param Component {any} hook 할 컴포넌트
 * @returns {any} intl, navigate, rest api 공통 에러 힘수를 포함한 component
 */
var withRestApi = function (Component) { return function (props) {
    // 아래와 같이 hook 내에서 또 다른 hook 을 부른다면, hook 을 사용하는 component 의 prop 가 변경 되면
    // 무조건 컴포넌트를 unmount, mount 하므로 이렇게 사용 해서는 안 된다.
    // const ComponentIntl = injectIntl(Component);
    // const ComponentWithNavigate = withNavigate(ComponentIntl);
    var navigate = (0, react_router_dom_1.useNavigate)();
    var location = (0, react_router_dom_1.useLocation)();
    var params = (0, react_router_dom_1.useParams)();
    var nprops = __assign(__assign({}, props), params);
    /**
     * rest api response 를 받았을 때, 공통 에러를 처리 한다.
     *
     * @param resp {any} redux-thunk 를 통해 받은 rest api response
     * @param intl {IntlShape} intl object
     * @param errMsgId {string | undefined} rest api 에러시 사용할 메시지 텍스트 아이디
     * @param movePage {any | undefined} 에러 발생시 이동하기 위한 movePage 함수. redux movePage. hook 을 사용하는 곳에서 redux movePage 를 포함하면 값을 줄 필요 없다
     * @returns {boolean} true 일 경우 rest api 에러 발생, false 라면 에러 발생 하지 않음
     */
    var isApiError = function (resp, intl, errMsgId, movePage) {
        var msgId = errMsgId || 'overall.apiFailed';
        // redux-thunk 를 통해서 서버에서 받은 메시지는 resp.payload 에 들어 있음.
        if (!resp || !resp.payload || !resp.payload.ckError) {
            antd_1.message.error(intl.formatMessage({ id: msgId }, { p1: '' }));
            return true;
        }
        if (resp.payload.ckError !== DkValues_1.API_RETURN_CODE.SUCCESS) {
            antd_1.message.error(intl.formatMessage({ id: msgId }, { p1: resp.payload.ckMessage }));
            // 인증 실패 이기 때문에, 인증 실패 페이지로 이동 시킨다.
            if (resp.payload.ckError === DkValues_1.API_RETURN_CODE.INVALID_AUTH) {
                if (movePage) {
                    movePage(CkUtils_1.default.getSvcURLPath(DkValues_1.DOTENV.URL_PATH_NO_AUTH), navigate);
                }
                else if (nprops.movePage) {
                    nprops.movePage(CkUtils_1.default.getSvcURLPath(DkValues_1.DOTENV.URL_PATH_NO_AUTH), navigate);
                }
                else {
                    console.error('not set movePage function.');
                }
            }
            return true;
        }
        return false;
    };
    return react_1.default.createElement(Component, __assign({}, nprops, { navigate: navigate, location: location, isApiError: isApiError }));
}; };
exports.default = withRestApi;
