"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable import/no-extraneous-dependencies,no-param-reassign */
var core_1 = __importDefault(require("crypto-js/core"));
var md5_1 = __importDefault(require("crypto-js/md5"));
var sha256_1 = __importDefault(require("crypto-js/sha256"));
var hmac_sha256_1 = __importDefault(require("crypto-js/hmac-sha256"));
var enc_base64_1 = __importDefault(require("crypto-js/enc-base64"));
var enc_utf8_1 = __importDefault(require("crypto-js/enc-utf8"));
var enc_hex_1 = __importDefault(require("crypto-js/enc-hex"));
var aes_1 = __importDefault(require("crypto-js/aes"));
var pad_pkcs7_1 = __importDefault(require("crypto-js/pad-pkcs7"));
var DkValues_1 = require("../DkValues");
var CkStorage_1 = __importDefault(require("./CkStorage"));
/**
 * hash 또는 암호화 함수 모음.
 * crypto-js 사용시 필요한 것만 import 해야 최종 결과물에 용량이 작아짐.
 */
var CkCrypto = /** @class */ (function () {
    function CkCrypto() {
    }
    /**
     * api key, api secret 를 local storage 또는 환경 설정에서 찾는다.
     * @private
     */
    CkCrypto.findApiKeyAndSecret = function () {
        var apiKeySecret = CkStorage_1.default.find(DkValues_1.DOTENV.KEY_API_KEY_SECRET);
        if (!apiKeySecret || !apiKeySecret.apiKey || !apiKeySecret.apiSecret) {
            CkCrypto.API_KEY = DkValues_1.API_CONFIG.KEY;
            CkCrypto.API_SECRET = DkValues_1.API_CONFIG.SECRET;
            return;
        }
        CkCrypto.READ_API_KEY_SCRET = true;
        CkCrypto.API_KEY = apiKeySecret.apiKey;
        CkCrypto.API_SECRET = apiKeySecret.apiSecret;
    };
    /**
     * ckstack 에서 사용하는 hmac-sha256 값을 구한다. Rest API 인증 처리시에 사용 됨.
     *
     * @param method {HTTP_METHOD} http request method
     * @param urlPath {string} api endpoint 의 url path. '?' 뒤에 붙어 있는 query string 은 제외 한다.
     * @param requestBody {string | { [key: string]: any; } | undefined} request 시에 body 에 들어가는 값. json object 나 string 둘 다 사용 가능.
     * @param contentType {string | undefined} http header 의 content-type 값. undefined 이면, 'application/json' 으로 자동 사용 된다.
     * @param date {string | undefined} http header 의 h-date 로 들어가는 값. 값이 없으면 현재 시간으로 설정 된다.
     * @param secret {string | undefined} signature 값을 만들기 위한 api secret 값. 값이 없으면 local storage 에 저장된 값이나, DkValues.API_CONFIG 에 설정된 값이 사용 된다.
     * @returns {{ signature: string; hdate: string; }} hmac-sha256 으로 만들어진 signature 와 signature 만들때 사용된 hdate 를 리턴 한다.
     * @private
     */
    CkCrypto.hmacSha256Hash2 = function (method, urlPath, requestBody, contentType, date, secret) {
        // 기본 api key, api secret 를 준비 한다.
        if (!secret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var md5Body = '';
        if (requestBody) {
            var rBody = '';
            if (typeof requestBody === 'object') {
                try {
                    rBody = JSON.stringify(requestBody);
                }
                catch (err) {
                    console.error("[".concat(this.name, "]invalid request body json for hmac-sha256. [").concat(requestBody, "]"));
                }
            }
            else {
                rBody = requestBody;
            }
            if (rBody.length > 0) {
                md5Body = CkCrypto.md5Hash(rBody).toString();
            }
        }
        console.log("[".concat(this.name, "] request md5 body [").concat(md5Body, "]"));
        var cType = (contentType === undefined ? 'application/json' : contentType);
        var hdate = date || (new Date()).toUTCString();
        var asecr = secret || CkCrypto.API_SECRET;
        var signaturePlain = "".concat(method.toUpperCase(), "\n").concat(md5Body, "\n").concat(cType, "\n").concat(hdate, "\n").concat(urlPath);
        console.log("[".concat(this.name, "] signature [").concat(signaturePlain, "], secret [").concat(asecr, "]"));
        var signatureSha = (0, hmac_sha256_1.default)(signaturePlain, asecr);
        // 서버에서 base64 로 결과를 내기 때문에, 동일하게 바꾼다.
        var signature = enc_base64_1.default.stringify(signatureSha);
        console.log("[".concat(this.name, "] hmac-sha256 signature [").concat(signature, "]"));
        return { signature: signature, hdate: hdate };
    };
    /**
     * ckstack 에서 사용하는 파일 업로드용 hmac-sha256 값을 구한다. Rest API 인증 처리시에 사용 됨.
     *
     * @param urlPath {string} api endpoint 의 url path. '?' 뒤에 붙어 있는 query string 은 제외 한다.
     * @param date {string | undefined} http header 의 h-date 로 들어가는 값. 값이 없으면 현재 시간으로 설정 된다.
     * @param secret {string | undefined} signature 값을 만들기 위한 api secret 값. 값이 없으면 local storage 에 저장된 값이나, DkValues.API_CONFIG 에 설정된 값이 사용 된다.
     * @returns {{ signature: string; hdate: string; }} hmac-sha256 으로 만들어진 signature 와 signature 만들때 사용된 hdate 를 리턴 한다.
     * @private
     */
    CkCrypto.hmacSha256HashForFile2 = function (urlPath, date, secret) {
        // 기본 api key, api secret 를 준비 한다.
        if (!secret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var md5Body = CkCrypto.md5Hash(DkValues_1.DOTENV.FILE_KEY).toString();
        console.log("[".concat(this.name, "] request md5 body [").concat(md5Body, "]"));
        var hdate = date || (new Date()).toUTCString();
        var asecr = secret || CkCrypto.API_SECRET;
        var signaturePlain = "".concat(DkValues_1.HTTP_METHOD.POST, "\n").concat(md5Body, "\n").concat(hdate, "\n").concat(urlPath);
        console.log("[".concat(this.name, "] signature [").concat(signaturePlain, "], secret [").concat(asecr, "]"));
        var signatureSha = (0, hmac_sha256_1.default)(signaturePlain, asecr);
        // 서버에서 base64 로 결과를 내기 때문에, 동일하게 바꾼다.
        var signature = enc_base64_1.default.stringify(signatureSha);
        console.log("[".concat(this.name, "] hmac-sha256 signature [").concat(signature, "]"));
        return { signature: signature, hdate: hdate };
    };
    /**
     * open/bearer 타입의 rest api 호출을 위한 http header 값을 구한다.
     *
     * @param method {HTTP_METHOD} http request method
     * @param urlPath {string} api endpoint 의 url path. '?' 뒤에 붙어 있는 query string 은 제외 한다.
     * @param requestBody {string | { [key: string]: any; } | undefined} request 시에 body 에 들어가는 값. json object 나 string 둘 다 사용 가능.
     * @param acceptLang {string | undefined} http header 의 accept-lang 에 들어가는 값. 값이 없으면 'ko' 로 자동 설정 된다.
     * @param contentType {string | undefined} http header 의 content-type 값. undefined 이면, 'application/json' 으로 자동 사용 된다.
     * @param hDate {string | undefined} http header 의 h-date 로 들어가는 값. 값이 없으면 현재 시간으로 설정 된다.
     * @param apiKeyOrAccessToken {string | undefined} api secret 과 매핑 되는 api key 값. isBearer 가 true 라면 access token 값 이다.
     * @param apiSecret {string | undefined} signature 값을 만들기 위한 api secret 값. 값이 없으면 local storage 에 저장된 값이나, DkValues.API_CONFIG 에 설정된 값이 사용 된다.
     * @param isBearer {boolean | undefined} open 형태의 rest api header 를 만들지, bearer 형태의 rest api header 를 만들지 구분. true 이면 bearer 형태의 api header 를 만든다.
     * @returns {{ [key: string]: string; }} rest api 호출 할때 사용할 axios 용 기본 http header 를 만들어 리턴 한다.
     * @private
     */
    CkCrypto.getAPIHeader = function (method, urlPath, requestBody, acceptLang, contentType, hDate, apiKeyOrAccessToken, apiSecret, isBearer) {
        // 기본 api key, api secret 를 준비 한다.
        if (!apiSecret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var sig = CkCrypto.hmacSha256Hash2(method, urlPath, requestBody, contentType, hDate, apiSecret);
        var aKey = apiKeyOrAccessToken || CkCrypto.API_KEY;
        var type = isBearer ? 'Bearer' : 'Open';
        var ret = {
            Accept: 'application/json',
            'Accept-Language': acceptLang || 'ko',
            'H-Date': sig.hdate,
            'H-Authorization': "".concat(type, " ").concat(aKey, ":").concat(sig.signature),
        };
        if (contentType) {
            ret['Content-Type'] = contentType;
        }
        return ret;
    };
    /**
     * open/bearer 타입의 파일 업로드를 위한 rest api 호출을 위한 http header 값을 구한다.
     *
     * @param urlPath {string} api endpoint 의 url path. '?' 뒤에 붙어 있는 query string 은 제외 한다.
     * @param acceptLang {string | undefined} http header 의 accept-lang 에 들어가는 값. 값이 없으면 'ko' 로 자동 설정 된다.
     * @param hDate {string | undefined} http header 의 h-date 로 들어가는 값. 값이 없으면 현재 시간으로 설정 된다.
     * @param apiKeyOrAccessToken {string | undefined} api secret 과 매핑 되는 api key 값. isBearer 가 true 라면 access token 값 이다.
     * @param apiSecret {string | undefined} signature 값을 만들기 위한 api secret 값. 값이 없으면 local storage 에 저장된 값이나, DkValues.API_CONFIG 에 설정된 값이 사용 된다.
     * @param isBearer {boolean | undefined} open 형태의 rest api header 를 만들지, bearer 형태의 rest api header 를 만들지 구분. true 이면 bearer 형태의 api header 를 만든다.
     * @returns {{ [key: string]: string; }} rest api 호출 할때 사용할 axios 용 기본 http header 를 만들어 리턴 한다.
     * @private
     */
    CkCrypto.getAPIHeaderForFile = function (urlPath, acceptLang, hDate, apiKeyOrAccessToken, apiSecret, isBearer) {
        // 기본 api key, api secret 를 준비 한다.
        if (!apiSecret) {
            CkCrypto.findApiKeyAndSecret();
        }
        var sig = CkCrypto.hmacSha256HashForFile2(urlPath, hDate, apiSecret);
        var aKey = apiKeyOrAccessToken || CkCrypto.API_KEY;
        var type = isBearer ? 'Bearer' : 'Open';
        var ret = {
            Accept: 'application/json',
            'Accept-Language': acceptLang || 'ko',
            'H-Date': sig.hdate,
            'H-Authorization': "".concat(type, " ").concat(aKey, ":").concat(sig.signature),
            'H-File-Key': DkValues_1.DOTENV.FILE_KEY,
        };
        return ret;
    };
    /**
     * Buffer 를 crypto-js 에서 사용하는 word array 로 변경 한다.
     * 참고: https://gist.github.com/artjomb/7ef1ee574a411ba0dd1933c1ef4690d1
     *
     * @param buf {Buffer} word array 로 변경 할 Buffer 값
     * @returns {CryptoCore.lib.WordArray} crypto-js 에서 사용하는 word array 로 변경하여 리턴 한다.
     * @private
     */
    CkCrypto.bufferToWordArray = function (buf) {
        var wa = [];
        for (var i = 0, len = buf.length; i < len; i += 1) {
            wa[(i / 4) | 0] |= buf[i] << (24 - 8 * i);
        }
        return core_1.default.lib.WordArray.create(wa, buf.length);
    };
    /**
     * crypto-js 의 word array 를 ArrayBuffer 로 변경 한다.
     * 참고1 : https://github.com/brix/crypto-js/issues/274
     * 참고2 : https://stackoverflow.com/questions/37228285/uint8array-to-arraybuffer
     *
     * @param wordArray {CryptoCore.lib.WordArray} 변경할 crypto-js word array
     * @return {ArrayBuffer} JS 의 array buffer 로 변경하여 리턴 한다.
     * @private
     */
    CkCrypto.wordArrayToBuffer = function (wordArray) {
        var l = wordArray.sigBytes;
        var words = wordArray.words;
        var result = new Uint8Array(l);
        var i = 0; // dst
        var j = 0; // src
        // eslint-disable-next-line no-constant-condition
        while (true) {
            // here i is a multiple of 4
            if (i === l) {
                break;
            }
            var w = words[j];
            j += 1;
            result[i] = (w & 0xff000000) >>> 24;
            i += 1;
            if (i === l) {
                break;
            }
            result[i] = (w & 0x00ff0000) >>> 16;
            i += 1;
            if (i === l) {
                break;
            }
            result[i] = (w & 0x0000ff00) >>> 8;
            i += 1;
            if (i === l) {
                break;
            }
            result[i] = (w & 0x000000ff);
            i += 1;
        }
        // return result;
        // 여기 까지 오면 result 에 Uint8Array 값이 설정 된다.
        return result.buffer.slice(result.byteOffset, result.byteLength + result.byteOffset);
    };
    /**
     * open 타입의 rest api 호출을 위한 axios option 값을 구한다.
     *
     * @param method {HTTP_METHOD} http request method
     * @param urlPath {string} api endpoint 의 url path. '?' 뒤에 붙어 있는 query string 은 제외 한다.
     * @param acceptLang {string} http header 의 accept-lang 에 들어가는 값. 특정 할 수 없으면 'en' 을 사용 한다.
     * @param requestBody {{ [key: string]: any; } | undefined} request 시에 body 에 들어가는 값. json object 나 string 둘 다 사용 가능.
     * @param qs {{ [key: string]: string; } | undefined} url 에 추가 되는 query string
     * @param contentType {string | undefined} http header 의 content-type 값. undefined 이면, 'application/json' 으로 자동 사용 된다.
     * @param hDate { string | undefined} http header 의 h-date 로 들어가는 값. 값이 없으면 현재 시간으로 설정 된다.
     * @param apiKey {string | undefined} api secret 과 매핑 되는 api key 값
     * @param apiSecret {string | undefined} signature 값을 만들기 위한 api secret 값. 값이 없으면 local storage 에 저장된 값이나, DkValues.API_CONFIG 에 설정된 값이 사용 된다.
     * @returns {RawAxiosRequestConfig} axios 를 사용하여 open 타입 rest api 호출 할때, axios(options) 으로 사용 할 수 있는 options 값을 리턴 한다.
     */
    CkCrypto.getOpenAPIAxiosOptions = function (method, urlPath, acceptLang, requestBody, qs, contentType, hDate, apiKey, apiSecret) {
        var ret = {
            method: method.toUpperCase(),
            url: "".concat(DkValues_1.API_HOST).concat(urlPath),
            headers: CkCrypto.getAPIHeader(method, urlPath, requestBody, acceptLang, contentType, hDate, apiKey, apiSecret),
            timeout: DkValues_1.API_CONFIG.TIMEOUT,
        };
        if (requestBody) {
            ret.data = requestBody;
        }
        if (qs) {
            ret.params = qs;
        }
        return ret;
    };
    /**
     * bearer 타입의 rest api 호출을 위한 axios option 값을 구한다.
     *
     * @param method {HTTP_METHOD} http request method
     * @param urlPath {string} api endpoint 의 url path. '?' 뒤에 붙어 있는 query string 은 제외 한다.
     * @param acceptLang {string} http header 의 accept-lang 에 들어가는 값. 특정 할 수 없으면 'en' 을 사용 한다.
     * @param requestBody {{ [key: string]: any; } | undefined} request 시에 body 에 들어가는 값. json object 나 string 둘 다 사용 가능.
     * @param qs {{ [key: string]: string; } | undefined} url 에 추가 되는 query string
     * @param contentType {string | undefined} http header 의 content-type 값. undefined 이면, 'application/json' 으로 자동 사용 된다.
     * @param hDate {string | undefined} http header 의 h-date 로 들어가는 값. 값이 없으면 현재 시간으로 설정 된다.
     * @param accessToken {string | undefined} 접속 토큰
     * @param apiSecret {string | undefined} signature 값을 만들기 위한 api secret 값. 값이 없으면 local storage 에 저장된 값이나, DkValues.API_CONFIG 에 설정된 값이 사용 된다.
     * @returns {RawAxiosRequestConfig} axios 를 사용하여 bearer 타입 rest api 호출 할때, axios(options) 으로 사용 할 수 있는 options 값을 리턴 한다.
     */
    CkCrypto.getBearerAPIAxiosOptions = function (method, urlPath, acceptLang, requestBody, qs, contentType, hDate, accessToken, apiSecret) {
        var ret = {
            method: method.toUpperCase(),
            url: "".concat(DkValues_1.API_HOST).concat(urlPath),
            headers: CkCrypto.getAPIHeader(method, urlPath, requestBody, acceptLang, contentType, hDate, accessToken, apiSecret, true),
            timeout: DkValues_1.API_CONFIG.TIMEOUT,
        };
        if (requestBody) {
            ret.data = requestBody;
        }
        if (qs) {
            ret.params = qs;
        }
        return ret;
    };
    CkCrypto.getBearerAPIAxiosOptionsForFile = function (file, urlPath, acceptLang, qs, hDate, accessToken, apiSecret) {
        var formData = new FormData();
        formData.append(DkValues_1.DOTENV.FILE_KEY, file);
        var ret = {
            method: DkValues_1.HTTP_METHOD.POST,
            url: "".concat(DkValues_1.API_HOST).concat(urlPath),
            headers: CkCrypto.getAPIHeaderForFile(urlPath, acceptLang, hDate, accessToken, apiSecret, true),
            timeout: DkValues_1.API_CONFIG.TIMEOUT,
            data: formData,
        };
        if (qs) {
            ret.params = qs;
        }
        return ret;
    };
    /**
     * string 값을 md5 한다.
     *
     * @param value {string | Buffer} md5 할 원본값
     * @returns {string} md5 hash 값을 리턴 한다.
     */
    CkCrypto.md5Hash = function (value) {
        if (typeof value === 'string') {
            return (0, md5_1.default)(value).toString();
        }
        var wordArr = CkCrypto.bufferToWordArray(value);
        return (0, md5_1.default)(wordArr).toString();
    };
    /**
     * string 값을 sha256 한다. 결과값으로 base64 로 인코딩 된 것을 리턴 한다.
     *
     * @param value {string} sha256 hash 할 값
     * @returns {string} base64 인코딩 된 값을 리턴 한다.
     */
    CkCrypto.sha256Hash = function (value) {
        return (0, sha256_1.default)(value).toString(enc_base64_1.default);
    };
    /**
     * string 이나 buffer 를 base64 로 인코딩 한다.
     *
     * @param value {string | Buffer} 인코딩할 소스
     * @returns {string} base64 로 인코딩 하여 리턴 한다.
     */
    CkCrypto.encodeBase64 = function (value) {
        var wordArr;
        if (typeof value === 'string') {
            wordArr = core_1.default.enc.Utf8.parse(value);
        }
        else {
            wordArr = CkCrypto.bufferToWordArray(value);
        }
        return enc_base64_1.default.stringify(wordArr);
    };
    /**
     * base64 로 인코딩 된 값을 디코딩 한다.
     *
     * @param value {string} base64 로 인코딩 된 값
     * @param isBuffer {boolean | undefined} 디코딩된 값이 string 이지 buffer 인지 구분. true 가 아니면 string 으로 취급 한다.
     * @returns {string | ArrayBuffer} 디코딩된 값을 리턴 한다.
     */
    CkCrypto.decodeBase64 = function (value, isBuffer) {
        var wordArr = enc_base64_1.default.parse(value);
        if (isBuffer) {
            return CkCrypto.wordArrayToBuffer(wordArr);
        }
        return wordArr.toString(core_1.default.enc.Utf8);
    };
    /**
     * string 이나 buffer 를 hex string 으로 인코딩 한다.
     *
     * @param value {string | Buffer} 인코딩할 소스
     * @returns {string} hex string 으로 인코딩 하여 리턴 한다.
     */
    CkCrypto.encodeHex = function (value) {
        var wordArr;
        if (typeof value === 'string') {
            wordArr = core_1.default.enc.Utf8.parse(value);
        }
        else {
            wordArr = CkCrypto.bufferToWordArray(value);
        }
        return core_1.default.enc.Hex.stringify(wordArr);
    };
    /**
     * hex string 으로 인코딩 된 값을 디코딩 한다.
     *
     * @param value {string} hex string 으로 인코딩 된 값
     * @param isBuffer {boolean | undefined} 디코딩된 값이 string 이지 buffer 인지 구분. true 가 아니면 string 으로 취급 한다.
     * @returns {string | ArrayBuffer} 디코딩된 값을 리턴 한다.
     */
    CkCrypto.decodeHex = function (value, isBuffer) {
        var wordArr = core_1.default.enc.Hex.parse(value);
        if (isBuffer) {
            return CkCrypto.wordArrayToBuffer(wordArr);
        }
        return core_1.default.enc.Utf8.stringify(wordArr);
    };
    /**
     * string 값을 aes 암호화 한다.
     *
     * @param value {string} aes 암호화 할 값
     * @param secretKey {string} 암호화 할때 사용할 secret key
     * @param iv {string} 암호화 할때 사용할 iv
     * @param isByHex {boolean | undefined} 암호화 결과값을 hex 로 받을지 여부. true 이면 hex 형태의 string 으로 리턴하고, 아니면 crypto js utf8 형태의 string 으로 리턴 한다.
     * @returns {string} aes 암호화한 값을 리턴 한다. mode 는 cbc, 패팅 PadPkcs7 으로 암호화 한 것이고 파라미터의 isByHex 값에 따라 리턴되는 스트링을 base64 또는 hex 인코딩 할지 결정 된다.
     */
    CkCrypto.encryptAES = function (value, secretKey, iv, isByHex) {
        var cipher = aes_1.default.encrypt(value, enc_utf8_1.default.parse(secretKey), {
            iv: enc_utf8_1.default.parse(iv),
            padding: pad_pkcs7_1.default,
            mode: core_1.default.mode.CBC,
        });
        // return by hex
        if (isByHex) {
            var word = enc_utf8_1.default.parse(cipher.toString());
            return enc_hex_1.default.stringify(word);
        }
        // return by base64
        return cipher.toString();
    };
    /**
     * aes 암호화 한 값을 푼다.
     *
     * @param value {string} aes 로 암호화 된 값
     * @param secretKey {string} 암호화를 풀기 위한 secret key
     * @param iv {string} 암호화를 풀기 위한 iv
     * @param isByHex {boolean | undefined} decrypt 할 값이 hex 형태 인지 아닌지 여부. true 이면 hex 형태. encryptAES 에서 isByHex 를 true 로 한 결과값이면 decrypt 시에도 isByHex 를 true 로 처리 해야 한다.
     * @returns {string} aes 로 암호화 된 값을 풀어서 리턴 한다. mode 는 cbc, 패팅 PadPkcs7 으로 aes 암호화 된 값을 푸는 것이고, isByHex 에 따라 input 되는 스트링이 hex 스트링인지, base64 스트링인지 구분 한다.
     */
    CkCrypto.decryptAES = function (value, secretKey, iv, isByHex) {
        // hex 로 찍힌 것을
        if (isByHex) {
            var word = enc_hex_1.default.parse(value);
            value = enc_utf8_1.default.stringify(word);
        }
        var decipher = aes_1.default.decrypt(value, enc_utf8_1.default.parse(secretKey), {
            iv: enc_utf8_1.default.parse(iv),
            padding: pad_pkcs7_1.default,
            mode: core_1.default.mode.CBC,
        });
        return decipher.toString(enc_utf8_1.default);
    };
    /** local storage 에서 api key, api secret 를 조회 해서 값을 설정 했는지 여부 */
    CkCrypto.READ_API_KEY_SCRET = false;
    /** local storage 에서 찾거나 환경 설정에서 읽은 rest api 용 api key */
    CkCrypto.API_KEY = '';
    /** local storage 에서 찾거나 환경 설정에서 읽은 rest api 용 api secret */
    CkCrypto.API_SECRET = '';
    return CkCrypto;
}());
exports.default = CkCrypto;
