"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var moment = __importStar(require("moment-timezone"));
var CkTime = /** @class */ (function () {
    function CkTime() {
    }
    /**
     * 타임존 설정을 한다. 호출 되면, 이후는 동일한 값으로 사용 된다.
     *
     * - 한국 : Asia/Seoul
     * - 영국 : Europe/London
     *
     * @param timeZone {string} 타임존 스트링
     * @returns {void} 리턴값 없음
     */
    CkTime.init = function (timeZone) {
        CkTime.TZ = timeZone;
    };
    /**
     * Get the timestamp of the previous date by month, based on tm.
     *
     * @param tm {number} 기준 시간의 timestamp
     * @param month {number} 이전 월을 구할 month 값. 가령 1이면 기준 timestamp 대비 한달 이전의 timestamp 를 리턴 한다.
     * @param isMilli {boolean | undefined} milli-sec 를 사용할지, second 를 사용지 여부. true 이면 tm 을 milli-sec 값으로 전달해야 하며, 리턴도 milli-sec 로 리턴 된다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {number} 월 단위 이전 날짜의 timestamp 를 리턴 한다. 초 단위 인지, milli-sec 단위 인지는 요청 파라미터인 isMilli 에 따라 다르다.
     */
    CkTime.beforeMonth = function (tm, month, isMilli, timeZone) {
        var _timezone = timeZone || CkTime.TZ;
        if (isMilli) {
            return moment.tz(tm, _timezone).subtract(month, 'month').valueOf();
        }
        return Math.floor(moment.tz(tm * 1000, _timezone).subtract(month, 'month').valueOf() / 1000);
    };
    /**
     * Get timestamp of date after month based on tm.
     *
     * @param tm {number} 기준 시간의 timestamp
     * @param month {number} 다음 월을 구할 month 값. 가령 1이면 기준 timestamp 대비 한달 이후의 timestamp 를 리턴 한다.
     * @param isMilli {boolean | undefined} milli-sec 를 사용할지, second 를 사용지 여부. true 이면 tm 을 milli-sec 값으로 전달해야 하며, 리턴도 milli-sec 로 리턴 된다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {number} 월 단위 다음 날짜의 timestamp 를 리턴 한다. 초 단위 인지, milli-sec 단위 인지는 요청 파라미터인 isMilli 에 따라 다르다.
     */
    CkTime.afterMonth = function (tm, month, isMilli, timeZone) {
        var _timezone = timeZone || CkTime.TZ;
        if (isMilli) {
            return moment.tz(tm, _timezone).add(month, 'month').valueOf();
        }
        return Math.floor(moment.tz(tm * 1000, _timezone).add(month, 'month').valueOf() / 1000);
    };
    /**
     * 숫자로 된 timestamp 를 원하는 포맷의 날짜 스트링을 구한다.
     * tm 은 기본으로 sec 단위이고, 만일 milli-sec 단위 이면 isMilli 를 true 로 사용 한다.
     * format 에는 "YYYY/MM/DD HH:mm:ss" 형태의 값이 사용 된다.
     *
     * @param tm {number} 날짜 스트링을 구할 timestamp
     * @param format {string} 리턴 되는 날짜의 포맷
     * @param isMilli {boolean | undefined} milli-sec 를 사용할지, second 를 사용지 여부. true 이면 tm 을 milli-sec 값으로 전달해야 한다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {string} 원하는 포맷의 날짜 스트링을 리턴 한다.
     */
    CkTime.toString = function (tm, format, isMilli, timeZone) {
        var _timeZone = timeZone || CkTime.TZ;
        if (isMilli) {
            return moment.tz(tm, _timeZone).format(format);
        }
        return moment.tz(tm * 1000, _timeZone).format(format);
    };
    /**
     * string 형태의 datetime 값을 timestamp 숫자값으로 구한다.
     *
     * @param str {string} 입력 되는 날짜의 스트링 값. 가령 '2022/01/03 12:00:00' 형태의 값.
     * @param format {string} 입력 되는 날짜의 포맷
     * @param isMilli {boolean | undefined} 리턴 하는 timestamp 가 milli-sec 일지, second 일지 여부. true 이면 milli-sec 로 리턴 한다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {number} 날자 스트링에서 timestamp 값을 리턴 한다. 초 단위 인지 milli-sec 인지는 파라미터로 주어진 isMilli 에 따른다.
     */
    CkTime.toValue = function (str, format, isMilli, timeZone) {
        var _timeZone = timeZone || CkTime.TZ;
        var tm = moment.tz(str, format, _timeZone).valueOf();
        if (isMilli) {
            return tm;
        }
        return Math.floor(tm / 1000);
    };
    CkTime.TZ = 'Asia/Seoul';
    return CkTime;
}());
exports.default = CkTime;
