"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var uuid = __importStar(require("uuid"));
var DkValues_1 = require("../DkValues");
var CkStorage_1 = __importDefault(require("./CkStorage"));
/**
 * 유틸리티 함수 모음
 */
var CkUtils = /** @class */ (function () {
    function CkUtils() {
    }
    /**
     * uuid를 만든다. timestamp 값을 base 로 uuid 를 만든다.
     *
     * @param isContainDash {boolean | undefined} true 이면 dash 를 포함하는 36자리 uuid 를 만들고, true 가 아니면 32자리 uuid 를 만든다.
     * @returns {string} time base 로 만들어진 uuid 를 리턴 한다. v1 알고리즘으로 만든 uuid.
     */
    CkUtils.getUUID = function (isContainDash) {
        if (isContainDash === true) {
            return uuid.v1();
        }
        return uuid.v1().replace(/-/gi, '');
    };
    /**
     * uuid를 만든다. random 값으로 uuid 를 만든다.
     *
     * @param isContainDash {boolean | undefined} true 이면 dash 를 포함하는 36자리 uuid 를 만들고, true 가 아니면 32자리 uuid 를 만든다.
     * @returns {string} 랜덤으로 만들어진 uuid 를 리턴 한다. v4 알고리즘으로 만든 uuid.
     */
    CkUtils.getUUIDV4 = function (isContainDash) {
        if (isContainDash === true) {
            return uuid.v4();
        }
        return uuid.v4().replace(/-/gi, '');
    };
    /**
     * uuid를 만든다. name, namespace 를 base 로 uuid 를 만든다.
     * nameSpace 는 dash 가 포함된 uuid 형태의 값을 사용 하면 된다.
     *
     * @param name {string} uuid 를 만들때 사용하는 name. 주로 CkUtils.getUUID() + '-' + Date.now() 로 사용 한다.
     * @param nameSpace {string | undefined} uuid 를 만들때 사용하는 name space. 값을 주지 않으면 내부에서 uuidv4 로 값을 생성 한다.
     * @param isContainDash {boolean | undefined} true 이면 dash 를 포함하는 36자리 uuid 를 만들고, true 가 아니면 32자리 uuid 를 만든다.
     * @returns {string} v5 알고리즘으로 만든 uuid 를 리턴 한다.
     */
    CkUtils.getUUIDV5 = function (name, nameSpace, isContainDash) {
        var _namespace = nameSpace || CkUtils.getUUIDV4(true);
        if (isContainDash === true) {
            return uuid.v5(name, _namespace);
        }
        return uuid.v5(name, _namespace).replace(/-/gi, '');
    };
    /**
     * 설정된 url path prefix 가 포함된 url path 를 구한다.
     * url prefix 가 더해진 url path 를 만들어서 리턴 한다.
     *
     * @param path {string} prefix 가 붙지 않은 url path
     * @param params {{ [key: string]: string; } | undefined} url path 에 :param_list 등의 형태로 url path 가 들어가 있을 때, url path param 이 변경될 실제 값
     * @param isUpdateLastPage {boolean | undefined} 본 함수로 구하는 url path 를 last page 로 저장 할지 여부. true 일 경우 저장 한다.
     * @returns {string} url prefix 가 붙은 url path 를 리턴 한다.
     */
    CkUtils.getSvcURLPath = function (path, params, isUpdateLastPage) {
        var retPath = "".concat(DkValues_1.DOTENV.URL_PREFIX).concat(path).replace(/\/\//gi, '/');
        if (params && Object.keys(params).length > 0) {
            retPath = CkUtils.getReplacedURLPath(retPath, params);
        }
        if (isUpdateLastPage) {
            var pageInfo = {
                urlPath: retPath,
                tm: Date.now(),
            };
            // 저장 한다.
            CkStorage_1.default.save(DkValues_1.DOTENV.KEY_LAST_PAGE, pageInfo);
        }
        return retPath;
    };
    /**
     * URL 에 :param_offset 등이 있는 값 때문에, url path parameter 를 실제 값으로 변경 한다.
     *
     * @param urlPath {string | undefined} 값이 없으면 undefined 를 리턴 한다.
     * @param replaceValues {[key: string]: string;} replace 될 대상과 값. 키가 대상이고 값이 replace 된 값임
     * @returns {string | undefined} replace 된 url path 를 리턴 한다. 만일 urlPath 가 undefined 이면 undefined 를 리턴 한다.
     */
    CkUtils.getReplacedURLPath = function (urlPath, replaceValues) {
        if (!urlPath) {
            return undefined;
        }
        if (!replaceValues) {
            return urlPath;
        }
        var keys = Object.keys(replaceValues);
        var _urlPath = urlPath;
        var isHas = _urlPath.indexOf(':');
        if (isHas) {
            for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
                var key = keys_1[_i];
                _urlPath = _urlPath.replace(":".concat(key), replaceValues[key]);
            }
        }
        return _urlPath;
    };
    /**
     * cidr 의 허용하는 ip 범위를 구한다.
     *
     * 예1)
     * cidr 값이 39.118.41.11/32 이면
     * { startIP: '39.118.41.11', endIP: '39.118.41.11' } 가 리턴 된다. 시작과 끝이 같으므로 하나의 IP 만 가능
     *
     * 예2)
     * cidr 값이 39.118.41.11/30 이면
     * { startIP: '39.118.41.8', endIP: '39.118.41.11' } 가 리턴 된다. 8, 9, 10, 11 IP 만 가능
     *
     * 예3)
     * cidr 값이 39.118.41.11/23 이면
     * { startIP: '39.118.40.0', endIP: '39.118.41.255' } 가 리턴 된다.
     * 39.118.40.0 ~ 39.118.40.255, 39.118.41.0 ~ 39.118.41.255 IP 가능
     *
     * @param cidr {string} ip 허용 범위를 가져올 cidr 값
     * @param isPermitAsterica {boolean | undefined} cidr 에 asterica 를 사용 가능 한지 여부. cidr 이 asterica 라면 startIP, endIP 도 asterica 로 리턴 한다.
     * @returns {{ startIP: string; endIP: string; } | null} 허용하는 ip 범위를 리턴 한다. 범위를 구하지 못하면 null 을 리턴 한다.
     */
    CkUtils.getApplyIpByCIDR = function (cidr, isPermitAsterica) {
        if (!cidr || !cidr.trim()) {
            console.log("no cidr value [".concat(cidr, "]"));
            return null;
        }
        if (isPermitAsterica && cidr.trim() === '*') {
            return { startIP: '*', endIP: '*' };
        }
        var cidrs = cidr.trim().split('/');
        if (cidrs.length !== 2) {
            console.log("invalid cidr value [".concat(cidr, "]"));
            return null;
        }
        var flagNum = Number(cidrs[1]);
        if (Number.isNaN(flagNum) || flagNum > 32 || flagNum < 0) {
            console.log("invalid cidr ip flag [".concat(cidrs[1], "]"));
            return null;
        }
        var strCIDRIP = cidrs[0].split('.');
        if (strCIDRIP.length !== 4) {
            console.log("invalid cidr ip [".concat(cidrs[0], "]"));
            return null;
        }
        // 특정 숫자이면 바로 리턴 한다.
        if (flagNum === 32) {
            return { startIP: "".concat(cidrs[0]), endIP: "".concat(cidrs[0]) };
        }
        if (flagNum === 24) {
            return { startIP: "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".").concat(strCIDRIP[2], ".0"), endIP: "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".").concat(strCIDRIP[2], ".255") };
        }
        if (flagNum === 16) {
            return { startIP: "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".0.0"), endIP: "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".255.255") };
        }
        if (flagNum === 8) {
            return { startIP: "".concat(strCIDRIP[0], ".0.0.0"), endIP: "".concat(strCIDRIP[0], ".255.255.255") };
        }
        if (flagNum === 0) {
            return { startIP: '0.0.0.0', endIP: '255.255.255.255' };
        }
        // cidr 의 ip 를 4개의 숫자로 분리 한다.
        var cidrIps = [];
        for (var _i = 0, strCIDRIP_1 = strCIDRIP; _i < strCIDRIP_1.length; _i++) {
            var row = strCIDRIP_1[_i];
            cidrIps.push(Number(row));
        }
        var strFlag = '';
        for (var i = 0, flag = flagNum; i < flag; i += 1) {
            strFlag = "".concat(strFlag, "1");
        }
        for (var i = 0, rest = 32 - flagNum; i < rest; i += 1) {
            strFlag = "".concat(strFlag, "0");
        }
        // cidr 의 flag 를 4개의 숫자로 분리 한다.
        var cidrFlags = [
            parseInt(strFlag.substring(0, 8), 2),
            parseInt(strFlag.substring(8, 16), 2),
            parseInt(strFlag.substring(16, 24), 2),
            parseInt(strFlag.substring(24), 2),
        ];
        // flag 가 반영된 cidr ip 를 구한다.
        for (var i = 0; i < 4; i += 1) {
            // eslint-disable-next-line no-bitwise
            cidrIps[i] &= cidrFlags[i];
        }
        // 32 255.255.255.255
        // 24 255.255.255.000
        // 16 255.255.000.000
        // 8  255.000.000.000
        var ret = { startIP: '', endIP: '' };
        if (flagNum > 24) {
            for (var i = 0; i <= 255; i += 1) {
                // eslint-disable-next-line no-bitwise
                if ((i & cidrFlags[3]) === cidrIps[3]) {
                    if (ret.startIP) {
                        ret.endIP = "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".").concat(strCIDRIP[2], ".").concat(i);
                    }
                    else {
                        ret.startIP = "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".").concat(strCIDRIP[2], ".").concat(i);
                    }
                }
            }
        }
        else if (flagNum > 16) {
            for (var i = 0; i <= 255; i += 1) {
                // eslint-disable-next-line no-bitwise
                if ((i & cidrFlags[2]) === cidrIps[2]) {
                    if (ret.startIP) {
                        ret.endIP = "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".").concat(i, ".255");
                    }
                    else {
                        ret.startIP = "".concat(strCIDRIP[0], ".").concat(strCIDRIP[1], ".").concat(i, ".0");
                    }
                }
            }
        }
        else if (flagNum > 8) {
            for (var i = 0; i <= 255; i += 1) {
                // eslint-disable-next-line no-bitwise
                if ((i & cidrFlags[1]) === cidrIps[1]) {
                    if (ret.startIP) {
                        ret.endIP = "".concat(strCIDRIP[0], ".").concat(i, ".255.255");
                    }
                    else {
                        ret.startIP = "".concat(strCIDRIP[0], ".").concat(i, ".0.0");
                    }
                }
            }
        }
        else {
            for (var i = 0; i <= 255; i += 1) {
                // eslint-disable-next-line no-bitwise
                if ((i & cidrFlags[0]) === cidrIps[0]) {
                    if (ret.startIP) {
                        ret.endIP = "".concat(i, ".255.255.255");
                    }
                    else {
                        ret.startIP = "".concat(i, ".0.0.0");
                    }
                }
            }
        }
        return ret;
    };
    /**
     * redux-saga 에서 rest api 호출시 axios catch(error) 에서 공통으로 사용하는 에러 response
     *
     * @param apiKind {string} 에러 로그에 포함되는 api 구분
     * @param thunkAPI {object} createAsyncThunk 함수의 thunkAPI
     * @param err {Error} axios 호출시 에러로 받은 error object
     * @returns {object} axios error 발생시 받은 response body 값. response body 가 없으면 null
     */
    CkUtils.errorResponse = function (apiKind, thunkAPI, err) {
        var _a;
        // 에러 발생시 서버에서 받은 값을 payload 에 담아 넘기거나, null 을 담아 넘긴다.
        // @ts-ignore
        if (err && err.response) {
            // @ts-ignore
            console.warn("[rest-api] ".concat(apiKind, " failed. response.data [").concat(JSON.stringify(err.response.data), "]"));
            // @ts-ignore
            return thunkAPI.rejectWithValue((_a = err.response) === null || _a === void 0 ? void 0 : _a.data);
        }
        return thunkAPI.rejectWithValue(null);
    };
    /**
     * Rest API 로 받은 메뉴 데이터를 UI 에 사용 할 수 있는 형태로 파싱 한다.
     *
     * @param menus {IMenu[]} 서버에서 받은 menu 목록
     * @param withPageId {boolean | undefined} true 라면 메뉴명에 page id 도 포함 한다.
     * @returns {{ menuTree: Array<any>; menuMap: { [menu_key: string]: ISidebarMenuItem; } }} map 형태로 된 menu map 과 array 형태로된 menu tree 데이터를 리턴 한다.
     */
    CkUtils.parsingMenu = function (menus, withPageId) {
        if (!menus || menus.length <= 0) {
            return { menuTree: [], menuMap: {} };
        }
        var maxDepth = 0;
        // depth 별로 메뉴를 나눈다.
        // depth0, depth1, depth2, ... 를 키로 하여 메뉴 목록을 값으로 가진다.
        var depthMenuMap = {};
        var allMenus = {};
        for (var _i = 0, menus_1 = menus; _i < menus_1.length; _i++) {
            var row = menus_1[_i];
            // 서버에서 데이터 제외 하는 것으로 처리해서 주석 처리함.
            // 상위 메뉴 시리얼 넘버는 있는데, 상위 메뉴 리소스 아이디가 없으면 데이터가 깨진 것으로 판단하고 제외 시킨다.
            // if (row.parentOsrl !== undefined && row.parentOsrl > 0 && !row.parentId) {
            //     continue;
            // }
            var name_1 = row.name;
            if (withPageId && row.rcPageName) {
                name_1 += " (".concat(row.rcPageName, ")");
            }
            allMenus[row.id] = {
                key: row.id,
                label: name_1,
                title: name_1,
                icon: row.rcIcon || '',
                order: row.listOrder,
                pid: row.parentId,
                urlpath: row.urlPath || '',
                pageid: row.rcPageName || '',
                isfirst: row.isFirstPage.toString().toLowerCase(),
                params: row.extra,
                status: row.status || DkValues_1.STATUS.ENABLE,
            };
            maxDepth = Math.max(maxDepth, row.depth);
            var depthKey = "depth".concat(row.depth);
            if (depthMenuMap[depthKey]) {
                depthMenuMap[depthKey].push(allMenus[row.id]);
            }
            else {
                depthMenuMap[depthKey] = [allMenus[row.id]];
            }
        }
        for (var depth = maxDepth; depth > 0; depth -= 1) {
            var currDepthRows = depthMenuMap["depth".concat(depth)];
            var prevDepthRows = depthMenuMap["depth".concat(depth - 1)];
            for (var _a = 0, currDepthRows_1 = currDepthRows; _a < currDepthRows_1.length; _a++) {
                var currRow = currDepthRows_1[_a];
                for (var _b = 0, prevDepthRows_1 = prevDepthRows; _b < prevDepthRows_1.length; _b++) {
                    var prevRow = prevDepthRows_1[_b];
                    if (currRow.pid === prevRow.key) {
                        if (prevRow.children) {
                            prevRow.children.push(currRow);
                        }
                        else {
                            prevRow.children = [currRow];
                        }
                    }
                }
            }
        }
        // 위의 로직으로 depth0 에 모두 몰아 넣기 때문에, depth 0 을 sidebar 메뉴로 사용 하면 된다.
        return { menuTree: depthMenuMap.depth0, menuMap: allMenus };
    };
    /**
     * 서버에서 받은 지원하는 메뉴 목록에서 페이지 아이디에 맞는 메뉴 데이터를 찾는다. 만일 찾지 못하면 null 을 리턴 한다.
     *
     * @param pageId {string} 페이지 아이디
     * @param menuMap {{ [menu_key: string]: ISidebarMenuItem; })} 서버에서 받은 지원하는 전체 메뉴 데이터. redux Overall.sidebar.menuMap 데이터
     * @returns {ISidebarMenuItem | null} 데이터를 찾으면 메뉴 데이터를 리턴하고 찾지 못하면 null 을 리턴 한다.
     */
    CkUtils.getPageMenuData = function (pageId, menuMap) {
        var menuKeys = Object.keys(menuMap);
        for (var _i = 0, menuKeys_1 = menuKeys; _i < menuKeys_1.length; _i++) {
            var row = menuKeys_1[_i];
            if (menuMap[row].pageid === pageId) {
                return menuMap[row];
            }
        }
        return undefined;
    };
    /**
     * CkUtils.getPageMenuData 에서 구한 페이지의 메뉴 데이터에서 화면의 breadcrumb 에 표시할 데이터를 구한다.
     *
     * @param pageMenuData {ISidebarMenuItem} CkUtils.getPageMenuData 에서 구한 페이지의 메뉴 데이터
     * @param menuMap {{ [menu_key: string]: ISidebarMenuItem; })} 서버에서 받은 지원하는 전체 메뉴 데이터. redux Overall.sidebar.menuMap 데이터
     * @returns {ISidebarMenuItem[]} breadcrumb 에 표시할 메뉴 목록
     */
    CkUtils.getBreadcrumbPath = function (pageMenuData, menuMap) {
        var paths = [pageMenuData];
        var parentKey = pageMenuData.pid || '';
        var loopCount = 0;
        while (parentKey !== '') {
            // 혹시 잘못되어서 루프를 10번 이상 돌면 루프를 중지 한다.
            if (loopCount > 10) {
                break;
            }
            if (!menuMap[parentKey]) {
                break;
            }
            paths.push(menuMap[parentKey]);
            parentKey = menuMap[parentKey].pid || '';
            loopCount += 1;
        }
        if (paths.length > 0) {
            paths = paths.reverse();
        }
        return paths;
    };
    /**
     * CkUtils.getPageMenuData, CkUtils.getBreadcrumbPath 를 실행한 결과를 구한다. 페이지에서 동일한 패턴으로 사용하기 때문에 공통 처리를 추가함.
     *
     * @param pageId {string} 페이지 아이디
     * @param menuMap {{ [menu_key: string]: ISidebarMenuItem; })} 서버에서 받은 지원하는 전체 메뉴 데이터. redux Overall.sidebar.menuMap 데이터
     * @returns {{ menuData: ISidebarMenuItem | undefined; breadcrumb: Array<ISidebarMenuItem>; }} 페이지 메뉴 데이터와 breadcrumb 에서 사용할 메뉴 목록을 구한다.
     */
    CkUtils.getPageMenuDataWithBreadcrumb = function (pageId, menuMap) {
        var ret = {
            menuData: undefined,
            breadcrumb: [],
        };
        ret.menuData = CkUtils.getPageMenuData(pageId, menuMap);
        if (ret.menuData) {
            ret.breadcrumb = CkUtils.getBreadcrumbPath(ret.menuData, menuMap);
        }
        return ret;
    };
    /**
     * 숫자 형태의 소셜 구분값으로 부터 i18n text id 를 구한다.
     *
     * @param socialType {number} 소셜 구분
     * @returns {string} 소셜명 i18n text 를 리턴 한다.
     */
    CkUtils.getSocialName = function (socialType) {
        switch (socialType) {
            case 1:
                return 'overall.google';
            case 2:
                return 'overall.naver';
            case 3:
                return 'overall.kakao';
            case 4:
                return 'overall.apple';
            case 5:
                return 'overall.instagram';
            case 6:
                return 'overall.facebook';
            default:
                return 'overall.na';
        }
    };
    /**
     * 사이드바 메뉴 트리에 등록되지 않은 페이지의 메뉴 데이터를 만든다.
     * 서버에서 받지 않은 페이지를 breadcrumb 에 포함 시키기 위해서 사용 하는 함수 이다.
     *
     * @param pageTitle {string} 페이지 명
     * @param pageId {string | undefined} 페이지 아이디
     * @returns {ISidebarMenuItem} breadcrumb 에 추가할 임의의 페이지 데이터를 리턴 한다.
     */
    CkUtils.getCustomBreadcrumbItem = function (pageTitle, pageId) {
        return {
            key: DkValues_1.CUSTOM_BREADCRUMB_PAGE_KEY,
            label: pageTitle,
            title: pageTitle,
            icon: '',
            order: 0,
            urlpath: '',
            pageid: pageId || '',
        };
    };
    /**
     * jsoneditor(https://github.com/josdejong/jsoneditor#code-mode) 를 위한 language code 를 변환 한다.
     * jsoneditor 는 기본으로 en, es zh-CN, pt-BR, tr, ja, fr-FR, de, ru, ko 언어 코드를 지원 한다.
     *
     * @param langCode {string} 변환할 언어 코드
     * @returns {string} 변환된 언어 코드
     */
    CkUtils.getLocaleForJsonEditor = function (langCode) {
        var code = langCode.replace(/_/gi, '-');
        var codeArr = code.split('-');
        if (codeArr[0] === 'en' || codeArr[0] === 'es' || codeArr[0] === 'tr' || codeArr[0] === 'ja'
            || codeArr[0] === 'de' || codeArr[0] === 'ru' || codeArr[0] === 'ko') {
            return codeArr[0];
        }
        return code;
    };
    return CkUtils;
}());
exports.default = CkUtils;
