declare class CkTime {
    private static TZ;
    /**
     * 타임존 설정을 한다. 호출 되면, 이후는 동일한 값으로 사용 된다.
     *
     * - 한국 : Asia/Seoul
     * - 영국 : Europe/London
     *
     * @param timeZone {string} 타임존 스트링
     * @returns {void} 리턴값 없음
     */
    static init(timeZone: string): void;
    /**
     * Get the timestamp of the previous date by month, based on tm.
     *
     * @param tm {number} 기준 시간의 timestamp
     * @param month {number} 이전 월을 구할 month 값. 가령 1이면 기준 timestamp 대비 한달 이전의 timestamp 를 리턴 한다.
     * @param isMilli {boolean | undefined} milli-sec 를 사용할지, second 를 사용지 여부. true 이면 tm 을 milli-sec 값으로 전달해야 하며, 리턴도 milli-sec 로 리턴 된다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {number} 월 단위 이전 날짜의 timestamp 를 리턴 한다. 초 단위 인지, milli-sec 단위 인지는 요청 파라미터인 isMilli 에 따라 다르다.
     */
    static beforeMonth(tm: number, month: number, isMilli?: boolean, timeZone?: string): number;
    /**
     * Get timestamp of date after month based on tm.
     *
     * @param tm {number} 기준 시간의 timestamp
     * @param month {number} 다음 월을 구할 month 값. 가령 1이면 기준 timestamp 대비 한달 이후의 timestamp 를 리턴 한다.
     * @param isMilli {boolean | undefined} milli-sec 를 사용할지, second 를 사용지 여부. true 이면 tm 을 milli-sec 값으로 전달해야 하며, 리턴도 milli-sec 로 리턴 된다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {number} 월 단위 다음 날짜의 timestamp 를 리턴 한다. 초 단위 인지, milli-sec 단위 인지는 요청 파라미터인 isMilli 에 따라 다르다.
     */
    static afterMonth(tm: number, month: number, isMilli?: boolean, timeZone?: string): number;
    /**
     * 숫자로 된 timestamp 를 원하는 포맷의 날짜 스트링을 구한다.
     * tm 은 기본으로 sec 단위이고, 만일 milli-sec 단위 이면 isMilli 를 true 로 사용 한다.
     * format 에는 "YYYY/MM/DD HH:mm:ss" 형태의 값이 사용 된다.
     *
     * @param tm {number} 날짜 스트링을 구할 timestamp
     * @param format {string} 리턴 되는 날짜의 포맷
     * @param isMilli {boolean | undefined} milli-sec 를 사용할지, second 를 사용지 여부. true 이면 tm 을 milli-sec 값으로 전달해야 한다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {string} 원하는 포맷의 날짜 스트링을 리턴 한다.
     */
    static toString(tm: number, format: string, isMilli?: boolean, timeZone?: string): string;
    /**
     * string 형태의 datetime 값을 timestamp 숫자값으로 구한다.
     *
     * @param str {string} 입력 되는 날짜의 스트링 값. 가령 '2022/01/03 12:00:00' 형태의 값.
     * @param format {string} 입력 되는 날짜의 포맷
     * @param isMilli {boolean | undefined} 리턴 하는 timestamp 가 milli-sec 일지, second 일지 여부. true 이면 milli-sec 로 리턴 한다.
     * @param timeZone {string | undefined} 처리시에 사용할 타임존. Asia/Seoul 형태의 값임. 값이 없으면 CkTime.init 로 설정한 타임존을 사용하고, CkTime.init 를 하지 않았다면, Asia/Seoul 을 기본값으로 사용 한다.
     * @returns {number} 날자 스트링에서 timestamp 값을 리턴 한다. 초 단위 인지 milli-sec 인지는 파라미터로 주어진 isMilli 에 따른다.
     */
    static toValue(str: string, format: string, isMilli?: boolean, timeZone?: string): number;
}
export default CkTime;
